#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


# @ <SNIPPET-DRAW-PEPTIDE>
ifs = oechem.oemolistream()
flavor = (oechem.OEIFlavor_Generic_Default | oechem.OEIFlavor_FASTA_EmbeddedSMILES)

ifs.SetFlavor(oechem.OEFormat_FASTA, flavor)
ifs.SetFormat(oechem.OEFormat_FASTA)

fasta = """>
FAVS[[R4]COCC(C(=O)O)Cc1ccccc1]"""

ifs.openstring(fasta)
mol = oechem.OEGraphMol()
oechem.OEReadMolecule(ifs, mol)

image = oedepict.OEImage(400, 250)

opts = oegrapheme.OEPeptideDisplayOptions()
opts.SetInteractive(True)
oegrapheme.OEDrawPeptide(image, mol, opts)
oedepict.OEWriteImage("DrawPeptide.svg", image)
# @ </SNIPPET-DRAW-PEPTIDE>
oedepict.OEWriteImage("DrawPeptide.pdf", image)



# CONFIDENTIAL. (C) 2017 OpenEye Scientific Software Inc.
# All rights reserved.
# 
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO OPENEYE
# SCIENTIFIC SOFTWARE INC., AND IS SUBJECT TO THE FULL PROTECTION OF
# COPYRIGHT AND TRADESECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from OpenEye is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact OpenEye at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")


def swig_import_helper():
    from os.path import dirname
    import importlib.util

    spec = importlib.machinery.PathFinder().find_spec("_oechem", [dirname(__file__)])

    if spec is None:
        # OpenEye Import Statements
        spec = importlib.machinery.PathFinder().find_spec("libs",[dirname(__file__)])
    libs = importlib.util.module_from_spec(spec)

    import sys
    sys.modules[spec.name] = libs
    spec.loader.exec_module(libs)

    assert not sys.platform.startswith('win')

    _oespicoli = libs.OEGetModule('_oespicoli1521')
    return _oespicoli

_oespicoli = swig_import_helper()
del swig_import_helper

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import weakref


def GetMainDict() -> "PyObject *":
    return _oespicoli.GetMainDict()

def TypeToPyString(type: "void const *") -> "PyObject *":
    return _oespicoli.TypeToPyString(type)
class OEInternalFunctionPointer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _oespicoli.OEInternalFunctionPointer_swiginit(self, _oespicoli.new_OEInternalFunctionPointer(*args))

    def Add(self, b: "OEBase", tag: "unsigned int", data: "PyObject *") -> "bool":
        return _oespicoli.OEInternalFunctionPointer_Add(self, b, tag, data)
    __swig_destroy__ = _oespicoli.delete_OEInternalFunctionPointer

# Register OEInternalFunctionPointer in _oespicoli:
_oespicoli.OEInternalFunctionPointer_swigregister(OEInternalFunctionPointer)


def OEInternalGetGenericData(type: "void const *") -> "OEInternalFunctionPointer *":
    return _oespicoli.OEInternalGetGenericData(type)
import openeye.oechem as oechem
OEVoxelizeMethod_Distance = _oespicoli.OEVoxelizeMethod_Distance

OEVoxelizeMethod_Gaussian = _oespicoli.OEVoxelizeMethod_Gaussian

OEVoxelizeMethod_Blank = _oespicoli.OEVoxelizeMethod_Blank

OEVoxelizeMethod_Blur = _oespicoli.OEVoxelizeMethod_Blur


OEVoxelizeMethod_Default = OEVoxelizeMethod_Distance

OEPolygonizeMethod_Grasp = _oespicoli.OEPolygonizeMethod_Grasp

OEPolygonizeMethod_Compact = _oespicoli.OEPolygonizeMethod_Compact


OEPolygonizeMethod_Default = OEPolygonizeMethod_Grasp

OESurfaceFileType_UNDEFINED = _oespicoli.OESurfaceFileType_UNDEFINED

OESurfaceFileType_Grasp = _oespicoli.OESurfaceFileType_Grasp

OESurfaceFileType_OESurface = _oespicoli.OESurfaceFileType_OESurface

OEEdgeReductionType_MinimumDistance = _oespicoli.OEEdgeReductionType_MinimumDistance

OERibbonType_CAlpha = _oespicoli.OERibbonType_CAlpha

OERibbonType_Pretty = _oespicoli.OERibbonType_Pretty

OERibbonType_MAXTYPE = _oespicoli.OERibbonType_MAXTYPE


def GetFloatFromPyObject(outfloat: "float &", numberobj: "PyObject *") -> "bool":
    r"""GetFloatFromPyObject(float & outfloat, PyObject * numberobj) -> bool"""
    return _oespicoli.GetFloatFromPyObject(outfloat, numberobj)

def GetIntFromPyObject(outint: "unsigned int &", numberobj: "PyObject *") -> "bool":
    r"""GetIntFromPyObject(unsigned int & outint, PyObject * numberobj) -> bool"""
    return _oespicoli.GetIntFromPyObject(outint, numberobj)
class OESurface(oechem.OEBase):
    r"""Proxy of C++ OESpicoli::OESurface class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def CreateCopy(self) -> "OESystem::OEBase *":
        r"""CreateCopy(OESurface self) -> OEBase"""
        return _oespicoli.OESurface_CreateCopy(self)

    def GetDataType(self) -> "void const *":
        r"""GetDataType(OESurface self) -> void const *"""
        return _oespicoli.OESurface_GetDataType(self)

    def IsDataType(self, type: "void const *") -> "bool":
        r"""IsDataType(OESurface self, void const * type) -> bool"""
        return _oespicoli.OESurface_IsDataType(self, type)

    def __init__(self, *args):
        r"""
        __init__(OESurface self) -> OESurface
        __init__(OESurface self, OESurface rhs) -> OESurface
        __init__(OESurface self, OESpicoli::OESurfaceImpl const & rhs) -> OESurface
        """
        _oespicoli.OESurface_swiginit(self, _oespicoli.new_OESurface(*args))

    def IsValid(self):
      return _oespicoli.OESurface___nonzero__(self)


    __swig_destroy__ = _oespicoli.delete_OESurface

    def Clear(self) -> "void":
        r"""Clear(OESurface self)"""
        return _oespicoli.OESurface_Clear(self)

    def SetTitle(self, title: "char const *") -> "bool":
        r"""SetTitle(OESurface self, char const * title) -> bool"""
        return _oespicoli.OESurface_SetTitle(self, title)

    def GetTitle(self) -> "char const *":
        r"""GetTitle(OESurface self) -> char const *"""
        return _oespicoli.OESurface_GetTitle(self)

    def GetResolution(self) -> "float":
        r"""GetResolution(OESurface self) -> float"""
        return _oespicoli.OESurface_GetResolution(self)

    def GetProbeRadius(self) -> "float":
        r"""GetProbeRadius(OESurface self) -> float"""
        return _oespicoli.OESurface_GetProbeRadius(self)

    def GetNumVertices(self) -> "unsigned int":
        r"""GetNumVertices(OESurface self) -> unsigned int"""
        return _oespicoli.OESurface_GetNumVertices(self)

    def GetVertices(self, vertices: "float *") -> "bool":
        r"""GetVertices(OESurface self, float * vertices) -> bool"""
        return _oespicoli.OESurface_GetVertices(self, vertices)

    def SetNumVertices(self, n: "unsigned int") -> "bool":
        r"""SetNumVertices(OESurface self, unsigned int n) -> bool"""
        return _oespicoli.OESurface_SetNumVertices(self, n)

    def SetVertices(self, vertices: "float const *") -> "bool":
        r"""SetVertices(OESurface self, float const * vertices) -> bool"""
        return _oespicoli.OESurface_SetVertices(self, vertices)

    def GetNumTriangles(self) -> "unsigned int":
        r"""GetNumTriangles(OESurface self) -> unsigned int"""
        return _oespicoli.OESurface_GetNumTriangles(self)

    def GetTriangles(self, triangles: "unsigned int *") -> "bool":
        r"""GetTriangles(OESurface self, unsigned int * triangles) -> bool"""
        return _oespicoli.OESurface_GetTriangles(self, triangles)

    def SetNumTriangles(self, n: "unsigned int") -> "bool":
        r"""SetNumTriangles(OESurface self, unsigned int n) -> bool"""
        return _oespicoli.OESurface_SetNumTriangles(self, n)

    def SetTriangles(self, triangles: "unsigned int const *") -> "bool":
        r"""SetTriangles(OESurface self, unsigned int const * triangles) -> bool"""
        return _oespicoli.OESurface_SetTriangles(self, triangles)

    def IsNormalsSet(self) -> "bool":
        r"""IsNormalsSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsNormalsSet(self)

    def GetNormals(self, normals: "float *") -> "bool":
        r"""GetNormals(OESurface self, float * normals) -> bool"""
        return _oespicoli.OESurface_GetNormals(self, normals)

    def SetNormals(self, normals: "float const *") -> "bool":
        r"""SetNormals(OESurface self, float const * normals) -> bool"""
        return _oespicoli.OESurface_SetNormals(self, normals)

    def IsFaceNormalsSet(self) -> "bool":
        r"""IsFaceNormalsSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsFaceNormalsSet(self)

    def GetFaceNormals(self, faceNormals: "float *") -> "bool":
        r"""GetFaceNormals(OESurface self, float * faceNormals) -> bool"""
        return _oespicoli.OESurface_GetFaceNormals(self, faceNormals)

    def SetFaceNormals(self, faceNormals: "float const *") -> "bool":
        r"""SetFaceNormals(OESurface self, float const * faceNormals) -> bool"""
        return _oespicoli.OESurface_SetFaceNormals(self, faceNormals)

    def IsDistanceSet(self) -> "bool":
        r"""IsDistanceSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsDistanceSet(self)

    def GetDistance(self, distance: "float *") -> "bool":
        r"""GetDistance(OESurface self, float * distance) -> bool"""
        return _oespicoli.OESurface_GetDistance(self, distance)

    def GetDistanceElement(self, n: "unsigned int") -> "float":
        r"""GetDistanceElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetDistanceElement(self, n)

    def SetDistance(self, distance: "float const *") -> "bool":
        r"""SetDistance(OESurface self, float const * distance) -> bool"""
        return _oespicoli.OESurface_SetDistance(self, distance)

    def SetDistanceElement(self, n: "unsigned int", value: "float") -> "bool":
        r"""SetDistanceElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetDistanceElement(self, n, value)

    def IsPotentialSet(self) -> "bool":
        r"""IsPotentialSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsPotentialSet(self)

    def GetPotential(self, potential: "float *") -> "bool":
        r"""GetPotential(OESurface self, float * potential) -> bool"""
        return _oespicoli.OESurface_GetPotential(self, potential)

    def GetPotentialElement(self, n: "unsigned int") -> "float":
        r"""GetPotentialElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetPotentialElement(self, n)

    def SetPotential(self, potential: "float const *") -> "bool":
        r"""SetPotential(OESurface self, float const * potential) -> bool"""
        return _oespicoli.OESurface_SetPotential(self, potential)

    def SetPotentialElement(self, n: "unsigned int", value: "float") -> "bool":
        r"""SetPotentialElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetPotentialElement(self, n, value)

    def SetPotentialName(self, name: "char const *") -> "void":
        r"""SetPotentialName(OESurface self, char const * name)"""
        return _oespicoli.OESurface_SetPotentialName(self, name)

    def GetPotentialName(self) -> "char const *":
        r"""GetPotentialName(OESurface self) -> char const *"""
        return _oespicoli.OESurface_GetPotentialName(self)

    def IsCurvatureSet(self) -> "bool":
        r"""IsCurvatureSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsCurvatureSet(self)

    def GetCurvature(self, curvature: "float *") -> "bool":
        r"""GetCurvature(OESurface self, float * curvature) -> bool"""
        return _oespicoli.OESurface_GetCurvature(self, curvature)

    def GetCurvatureElement(self, n: "unsigned int") -> "float":
        r"""GetCurvatureElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetCurvatureElement(self, n)

    def SetCurvature(self, curvature: "float const *") -> "bool":
        r"""SetCurvature(OESurface self, float const * curvature) -> bool"""
        return _oespicoli.OESurface_SetCurvature(self, curvature)

    def SetCurvatureElement(self, n: "unsigned int", value: "float") -> "bool":
        r"""SetCurvatureElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetCurvatureElement(self, n, value)

    def IsAtomsSet(self) -> "bool":
        r"""IsAtomsSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsAtomsSet(self)

    def GetAtoms(self, atoms: "unsigned int *") -> "bool":
        r"""GetAtoms(OESurface self, unsigned int * atoms) -> bool"""
        return _oespicoli.OESurface_GetAtoms(self, atoms)

    def GetAtomsElement(self, n: "unsigned int") -> "unsigned int":
        r"""GetAtomsElement(OESurface self, unsigned int n) -> unsigned int"""
        return _oespicoli.OESurface_GetAtomsElement(self, n)

    def SetAtoms(self, atoms: "unsigned int const *") -> "bool":
        r"""SetAtoms(OESurface self, unsigned int const * atoms) -> bool"""
        return _oespicoli.OESurface_SetAtoms(self, atoms)

    def SetAtomsElement(self, n: "unsigned int", value: "unsigned int") -> "bool":
        r"""SetAtomsElement(OESurface self, unsigned int n, unsigned int value) -> bool"""
        return _oespicoli.OESurface_SetAtomsElement(self, n, value)

    def IsColorSet(self) -> "bool":
        r"""IsColorSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsColorSet(self)

    def GetColor(self, *args) -> "bool":
        r"""
        GetColor(OESurface self, unsigned char * color) -> bool
        GetColor(OESurface self, float * color) -> bool
        """
        return _oespicoli.OESurface_GetColor(self, *args)

    def SetColor(self, *args) -> "bool":
        r"""
        SetColor(OESurface self, unsigned char const * color) -> bool
        SetColor(OESurface self, float const * color) -> bool
        """
        return _oespicoli.OESurface_SetColor(self, *args)

    def SetColorElement(self, *args) -> "bool":
        r"""
        SetColorElement(OESurface self, unsigned int n, unsigned char r, unsigned char g, unsigned char b, unsigned char a=255) -> bool
        SetColorElement(OESurface self, unsigned int n, float r, float g, float b, float a=1.0) -> bool
        """
        return _oespicoli.OESurface_SetColorElement(self, *args)

    def IsVertexCliqueSet(self) -> "bool":
        r"""IsVertexCliqueSet(OESurface self) -> bool"""
        return _oespicoli.OESurface_IsVertexCliqueSet(self)

    def GetVertexClique(self, vertexClique: "unsigned int *") -> "bool":
        r"""GetVertexClique(OESurface self, unsigned int * vertexClique) -> bool"""
        return _oespicoli.OESurface_GetVertexClique(self, vertexClique)

    def GetVertexCliqueElement(self, n: "unsigned int") -> "unsigned int":
        r"""GetVertexCliqueElement(OESurface self, unsigned int n) -> unsigned int"""
        return _oespicoli.OESurface_GetVertexCliqueElement(self, n)

    def SetVertexClique(self, vertexClique: "unsigned int const *") -> "bool":
        r"""SetVertexClique(OESurface self, unsigned int const * vertexClique) -> bool"""
        return _oespicoli.OESurface_SetVertexClique(self, vertexClique)

    def SetVertexCliqueElement(self, n: "unsigned int", value: "unsigned int") -> "bool":
        r"""SetVertexCliqueElement(OESurface self, unsigned int n, unsigned int value) -> bool"""
        return _oespicoli.OESurface_SetVertexCliqueElement(self, n, value)

    def ClearVertexClique(self) -> "bool":
        r"""ClearVertexClique(OESurface self) -> bool"""
        return _oespicoli.OESurface_ClearVertexClique(self)

    def GetVerticesElement(self, n: "unsigned int") -> "float":
        r"""GetVerticesElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetVerticesElement(self, n)

    def SetVerticesElement(self, n: "unsigned int", value: "float") -> "bool":
        r"""SetVerticesElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetVerticesElement(self, n, value)

    def GetTrianglesElement(self, n: "unsigned int") -> "unsigned int":
        r"""GetTrianglesElement(OESurface self, unsigned int n) -> unsigned int"""
        return _oespicoli.OESurface_GetTrianglesElement(self, n)

    def SetTrianglesElement(self, n: "unsigned int", value: "unsigned int") -> "bool":
        r"""SetTrianglesElement(OESurface self, unsigned int n, unsigned int value) -> bool"""
        return _oespicoli.OESurface_SetTrianglesElement(self, n, value)

    def GetNormalsElement(self, n: "unsigned int") -> "float":
        r"""GetNormalsElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetNormalsElement(self, n)

    def SetNormalsElement(self, n: "unsigned int", value: "float") -> "bool":
        r"""SetNormalsElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetNormalsElement(self, n, value)

    def GetFaceNormalsElement(self, n: "unsigned int") -> "float":
        r"""GetFaceNormalsElement(OESurface self, unsigned int n) -> float"""
        return _oespicoli.OESurface_GetFaceNormalsElement(self, n)

    def SetFaceNormalsElement(self, n: "unsigned int", value: "float") -> "bool":
        r"""SetFaceNormalsElement(OESurface self, unsigned int n, float value) -> bool"""
        return _oespicoli.OESurface_SetFaceNormalsElement(self, n, value)

    def Sweep(self) -> "void":
        r"""Sweep(OESurface self)"""
        return _oespicoli.OESurface_Sweep(self)

    def GetVertex(self, *args) -> "PyObject *":
        r"""
        GetVertex(OESurface self, unsigned int n, float * vertex) -> bool
        GetVertex(OESurface self, unsigned int n) -> PyObject *
        """
        return _oespicoli.OESurface_GetVertex(self, *args)

    def SetVertex(self, *args) -> "PyObject *":
        r"""
        SetVertex(OESurface self, unsigned int n, float const * vertex) -> bool
        SetVertex(OESurface self, unsigned int n, PyObject * input) -> PyObject *
        """
        return _oespicoli.OESurface_SetVertex(self, *args)

    def GetTriangle(self, *args) -> "PyObject *":
        r"""
        GetTriangle(OESurface self, unsigned int n, unsigned int * triangle) -> bool
        GetTriangle(OESurface self, unsigned int n) -> PyObject *
        """
        return _oespicoli.OESurface_GetTriangle(self, *args)

    def SetTriangle(self, *args) -> "PyObject *":
        r"""
        SetTriangle(OESurface self, unsigned int n, unsigned int const * triangle) -> bool
        SetTriangle(OESurface self, unsigned int n, PyObject * input) -> PyObject *
        """
        return _oespicoli.OESurface_SetTriangle(self, *args)

    def GetNormal(self, *args) -> "PyObject *":
        r"""
        GetNormal(OESurface self, unsigned int n, float * normal) -> bool
        GetNormal(OESurface self, unsigned int n) -> PyObject *
        """
        return _oespicoli.OESurface_GetNormal(self, *args)

    def SetNormal(self, *args) -> "PyObject *":
        r"""
        SetNormal(OESurface self, unsigned int n, float const * normal) -> bool
        SetNormal(OESurface self, unsigned int n, PyObject * input) -> PyObject *
        """
        return _oespicoli.OESurface_SetNormal(self, *args)

    def GetFaceNormal(self, *args) -> "PyObject *":
        r"""
        GetFaceNormal(OESurface self, unsigned int n, float * normal) -> bool
        GetFaceNormal(OESurface self, unsigned int n) -> PyObject *
        """
        return _oespicoli.OESurface_GetFaceNormal(self, *args)

    def SetFaceNormal(self, *args) -> "PyObject *":
        r"""
        SetFaceNormal(OESurface self, unsigned int n, float const * normal) -> bool
        SetFaceNormal(OESurface self, unsigned int n, PyObject * input) -> PyObject *
        """
        return _oespicoli.OESurface_SetFaceNormal(self, *args)

    def GetColorElement(self, n: "unsigned int") -> "PyObject *":
        r"""GetColorElement(OESurface self, unsigned int n) -> PyObject *"""
        return _oespicoli.OESurface_GetColorElement(self, n)

    def GetColorElementF(self, n: "unsigned int") -> "PyObject *":
        r"""GetColorElementF(OESurface self, unsigned int n) -> PyObject *"""
        return _oespicoli.OESurface_GetColorElementF(self, n)

# Register OESurface in _oespicoli:
_oespicoli.OESurface_swigregister(OESurface)


def OEGetSurfaceCenterAndExtents(surf: "OESurface", center: "float *", extents: "float *") -> "void":
    r"""OEGetSurfaceCenterAndExtents(OESurface surf, float * center, float * extents)"""
    return _oespicoli.OEGetSurfaceCenterAndExtents(surf, center, extents)

def OESetSurface(obj: "OEBase", t: "char const *", s: "OESurface") -> "bool":
    r"""OESetSurface(OEBase obj, char const * t, OESurface s) -> bool"""
    return _oespicoli.OESetSurface(obj, t, s)

def OEGetSurface(obj: "OEBase", t: "char const *") -> "OESpicoli::OESurface const &":
    r"""OEGetSurface(OEBase obj, char const * t) -> OESurface"""
    return _oespicoli.OEGetSurface(obj, t)

def OEMakeMolecularSurface(*args) -> "bool":
    r"""
    OEMakeMolecularSurface(OESurface surf, OEMolBase mol, float resolution=0.5, float probeRadius=1.4, unsigned int polygonizeMethod=) -> bool
    OEMakeMolecularSurface(OESurface surf, float const * coords, float const * radii, int natoms, float resolution=0.5, float probeRadius=1.4, unsigned int polygonizeMethod=) -> bool
    """
    return _oespicoli.OEMakeMolecularSurface(*args)

def OEMakeProteinRibbonSurface(*args) -> "bool":
    r"""OEMakeProteinRibbonSurface(OESurface surf, OEMolBase mol, unsigned int type=) -> bool"""
    return _oespicoli.OEMakeProteinRibbonSurface(*args)

def OEMakeAccessibleSurface(*args) -> "bool":
    r"""
    OEMakeAccessibleSurface(OESurface surf, OEMolBase mol, float resolution=0.5, float probeRadius=1.4, unsigned int polygonizeMethod=) -> bool
    OEMakeAccessibleSurface(OESurface surf, float const * coords, float const * radii, int natoms, float resolution=0.5, float probeRadius=1.4, unsigned int polygonizeMethod=) -> bool
    """
    return _oespicoli.OEMakeAccessibleSurface(*args)

def OEMakeSurfaceFromGrid(*args) -> "bool":
    r"""
    OEMakeSurfaceFromGrid(OESurface surf, OEFixedFloatGrid grid, float contour) -> bool
    OEMakeSurfaceFromGrid(OESurface surf, OEFixedFloatGrid grid, float contour, float resolution) -> bool
    OEMakeSurfaceFromGrid(OESurface surf, OESystem::OESkewGrid const & grid, float contour) -> bool
    """
    return _oespicoli.OEMakeSurfaceFromGrid(*args)

def OEMakeGridFromSurface(*args) -> "bool":
    r"""OEMakeGridFromSurface(OESystem::OEScalarGrid & grid, OESurface surf, unsigned int method=) -> bool"""
    return _oespicoli.OEMakeGridFromSurface(*args)

def OEMakeBitGridFromSurface(*args) -> "bool":
    r"""
    OEMakeBitGridFromSurface(OESystem::OEScalarGrid & grid, OESurface surf, float spacing, float buffer) -> bool
    OEMakeBitGridFromSurface(OESystem::OEScalarGrid & grid, OESurface surf) -> bool
    """
    return _oespicoli.OEMakeBitGridFromSurface(*args)

def OEMakeVoidVolume(mol1: "OEMolBase", mol2: "OEMolBase", grid: "OESystem::OEScalarGrid &", resolution: "float", probeRad: "float"=1.4) -> "bool":
    r"""OEMakeVoidVolume(OEMolBase mol1, OEMolBase mol2, OESystem::OEScalarGrid & grid, float resolution, float probeRad=1.4) -> bool"""
    return _oespicoli.OEMakeVoidVolume(mol1, mol2, grid, resolution, probeRad)

def OEMakeComplexCavities(ligand: "OEMolBase", protein: "OEMolBase", surf: "OESurface", resolution: "float"=0.5, probeRad: "float"=1.4) -> "bool":
    r"""OEMakeComplexCavities(OEMolBase ligand, OEMolBase protein, OESurface surf, float resolution=0.5, float probeRad=1.4) -> bool"""
    return _oespicoli.OEMakeComplexCavities(ligand, protein, surf, resolution, probeRad)

def OEMakeCavitySurfaces(mol: "OEMolBase", surf: "OESurface", resolution: "float"=0.5, probeRadius: "float"=1.4) -> "bool":
    r"""OEMakeCavitySurfaces(OEMolBase mol, OESurface surf, float resolution=0.5, float probeRadius=1.4) -> bool"""
    return _oespicoli.OEMakeCavitySurfaces(mol, surf, resolution, probeRadius)

def OESurfaceToMoleculeDistance(surf: "OESurface", mol: "OEMolBase") -> "bool":
    r"""OESurfaceToMoleculeDistance(OESurface surf, OEMolBase mol) -> bool"""
    return _oespicoli.OESurfaceToMoleculeDistance(surf, mol)

def OECalculateSurfaceCurvature(surf: "OESurface", mol: "OEMolBase", probeRadius: "float"=1.4) -> "bool":
    r"""OECalculateSurfaceCurvature(OESurface surf, OEMolBase mol, float probeRadius=1.4) -> bool"""
    return _oespicoli.OECalculateSurfaceCurvature(surf, mol, probeRadius)

def OEMakeSphericalSurface(surf: "OESurface", center: "float *", radius: "float", level: "unsigned int"=4) -> "bool":
    r"""OEMakeSphericalSurface(OESurface surf, float * center, float radius, unsigned int level=4) -> bool"""
    return _oespicoli.OEMakeSphericalSurface(surf, center, radius, level)

def OEMakeEllipsoidSurface(surf: "OESurface", center: "float *", a: "float", b: "float", c: "float", dir1: "float *", dir2: "float *", dir3: "float *", level: "int"=4) -> "bool":
    r"""OEMakeEllipsoidSurface(OESurface surf, float * center, float a, float b, float c, float * dir1, float * dir2, float * dir3, int level=4) -> bool"""
    return _oespicoli.OEMakeEllipsoidSurface(surf, center, a, b, c, dir1, dir2, dir3, level)

def OEMakeBoxSurface(surf: "OESurface", center: "float const *", extents: "float const *") -> "bool":
    r"""OEMakeBoxSurface(OESurface surf, float const * center, float const * extents) -> bool"""
    return _oespicoli.OEMakeBoxSurface(surf, center, extents)

def OECalculateFaceNormals(surf: "OESurface") -> "bool":
    r"""OECalculateFaceNormals(OESurface surf) -> bool"""
    return _oespicoli.OECalculateFaceNormals(surf)

def OECalculateNormals(surf: "OESurface") -> "bool":
    r"""OECalculateNormals(OESurface surf) -> bool"""
    return _oespicoli.OECalculateNormals(surf)

def OESetSurfacePotentials(surf: "OESurface", grid: "OESystem::OEScalarGrid const &") -> "bool":
    r"""OESetSurfacePotentials(OESurface surf, OESystem::OEScalarGrid const & grid) -> bool"""
    return _oespicoli.OESetSurfacePotentials(surf, grid)

def OESetSurfaceColor(*args) -> "bool":
    r"""
    OESetSurfaceColor(OESurface surf, unsigned char r, unsigned char g, unsigned char b, unsigned char a=255) -> bool
    OESetSurfaceColor(OESurface surf, float r, float g, float b, float a=1.0) -> bool
    """
    return _oespicoli.OESetSurfaceColor(*args)

def OEInvertSurface(surf: "OESurface") -> "bool":
    r"""OEInvertSurface(OESurface surf) -> bool"""
    return _oespicoli.OEInvertSurface(surf)

def OESurfaceVolume(surf: "OESurface") -> "float":
    r"""OESurfaceVolume(OESurface surf) -> float"""
    return _oespicoli.OESurfaceVolume(surf)

def OESurfaceArea(surf: "OESurface") -> "float":
    r"""OESurfaceArea(OESurface surf) -> float"""
    return _oespicoli.OESurfaceArea(surf)

def OESurfaceCliqueVolume(surf: "OESurface", clique: "unsigned int") -> "float":
    r"""OESurfaceCliqueVolume(OESurface surf, unsigned int clique) -> float"""
    return _oespicoli.OESurfaceCliqueVolume(surf, clique)

def OESurfaceCliqueCentroid(surf: "OESurface", clique: "unsigned int", centroid: "float *") -> "bool":
    r"""OESurfaceCliqueCentroid(OESurface surf, unsigned int clique, float * centroid) -> bool"""
    return _oespicoli.OESurfaceCliqueCentroid(surf, clique, centroid)

def OESurfaceCliqueArea(surf: "OESurface", clique: "unsigned int") -> "float":
    r"""OESurfaceCliqueArea(OESurface surf, unsigned int clique) -> float"""
    return _oespicoli.OESurfaceCliqueArea(surf, clique)

def OEMakeConnectedSurfaceCliques(surf: "OESurface") -> "unsigned int":
    r"""OEMakeConnectedSurfaceCliques(OESurface surf) -> unsigned int"""
    return _oespicoli.OEMakeConnectedSurfaceCliques(surf)

def OECalculateTriangleAreas(surf: "OESurface", areas: "float *") -> "bool":
    r"""OECalculateTriangleAreas(OESurface surf, float * areas) -> bool"""
    return _oespicoli.OECalculateTriangleAreas(surf, areas)

def OESurfaceIsOpen(surf: "OESurface") -> "bool":
    r"""OESurfaceIsOpen(OESurface surf) -> bool"""
    return _oespicoli.OESurfaceIsOpen(surf)

def OEMakeCliqueSurface(newsurf: "OESurface", surf: "OESurface", clique: "unsigned int") -> "bool":
    r"""OEMakeCliqueSurface(OESurface newsurf, OESurface surf, unsigned int clique) -> bool"""
    return _oespicoli.OEMakeCliqueSurface(newsurf, surf, clique)

def OESurfaceCropToClique(surf: "OESurface", clique: "unsigned int") -> "bool":
    r"""OESurfaceCropToClique(OESurface surf, unsigned int clique) -> bool"""
    return _oespicoli.OESurfaceCropToClique(surf, clique)

def OEAddSurfaces(surf1: "OESurface", surf2: "OESurface") -> "bool":
    r"""OEAddSurfaces(OESurface surf1, OESurface surf2) -> bool"""
    return _oespicoli.OEAddSurfaces(surf1, surf2)

def OERotateSurface(surf: "OESurface", rmat: "float *") -> "void":
    r"""OERotateSurface(OESurface surf, float * rmat)"""
    return _oespicoli.OERotateSurface(surf, rmat)

def OETranslateSurface(surf: "OESurface", trans: "float *") -> "void":
    r"""OETranslateSurface(OESurface surf, float * trans)"""
    return _oespicoli.OETranslateSurface(surf, trans)

def OETransformSurface(surf: "OESurface", trans: "OETrans") -> "void":
    r"""OETransformSurface(OESurface surf, OETrans trans)"""
    return _oespicoli.OETransformSurface(surf, trans)

def OESplitSurfaceByAtoms(*args) -> "bool":
    r"""
    OESplitSurfaceByAtoms(OESurface newsurf, OESurface surf, OEMolBase mol, double maxDist=4.0) -> bool
    OESplitSurfaceByAtoms(OESurface surf, OEMolBase mol, double maxDist=4.0) -> bool
    """
    return _oespicoli.OESplitSurfaceByAtoms(*args)

def OESmoothSurfaceEdges(surf: "OESurface") -> "bool":
    r"""OESmoothSurfaceEdges(OESurface surf) -> bool"""
    return _oespicoli.OESmoothSurfaceEdges(surf)
OE_OESPICOLI_VERSION = _oespicoli.OE_OESPICOLI_VERSION


def OESpicoliGetRelease() -> "char const *":
    r"""OESpicoliGetRelease() -> char const *"""
    return _oespicoli.OESpicoliGetRelease()

def OESpicoliGetVersion() -> "unsigned int":
    r"""OESpicoliGetVersion() -> unsigned int"""
    return _oespicoli.OESpicoliGetVersion()

def OESpicoliGetArch() -> "char const *":
    r"""OESpicoliGetArch() -> char const *"""
    return _oespicoli.OESpicoliGetArch()

def OESpicoliGetPlatform() -> "char const *":
    r"""OESpicoliGetPlatform() -> char const *"""
    return _oespicoli.OESpicoliGetPlatform()

def OESpicoliIsLicensed(feature: "char const *"=None, expdate: "unsigned int *"=None) -> "bool":
    r"""OESpicoliIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool"""
    return _oespicoli.OESpicoliIsLicensed(feature, expdate)

def OESpicoliGetLicensee(*args) -> "std::string":
    r"""
    OESpicoliGetLicensee(std::string & licensee) -> bool
    OESpicoliGetLicensee() -> std::string
    """
    return _oespicoli.OESpicoliGetLicensee(*args)

def OESpicoliGetSite(*args) -> "std::string":
    r"""
    OESpicoliGetSite(std::string & site) -> bool
    OESpicoliGetSite() -> std::string
    """
    return _oespicoli.OESpicoliGetSite(*args)

def OEIsReadableSurface(*args) -> "bool":
    r"""
    OEIsReadableSurface(unsigned int type) -> bool
    OEIsReadableSurface(std::string const & filename) -> bool
    """
    return _oespicoli.OEIsReadableSurface(*args)

def OEIsWriteableSurface(*args) -> "bool":
    r"""
    OEIsWriteableSurface(unsigned int type) -> bool
    OEIsWriteableSurface(std::string const & filename) -> bool
    """
    return _oespicoli.OEIsWriteableSurface(*args)

def OEGetSurfaceFileType(ext: "char const *") -> "unsigned int":
    r"""OEGetSurfaceFileType(char const * ext) -> unsigned int"""
    return _oespicoli.OEGetSurfaceFileType(ext)

def OEGetSurfaceFormatExtension(tag: "unsigned int") -> "char const *":
    r"""OEGetSurfaceFormatExtension(unsigned int tag) -> char const *"""
    return _oespicoli.OEGetSurfaceFormatExtension(tag)

def OEGetSurfaceFormatString(tag: "unsigned int") -> "char const *":
    r"""OEGetSurfaceFormatString(unsigned int tag) -> char const *"""
    return _oespicoli.OEGetSurfaceFormatString(tag)

def OEReadSurface(*args) -> "bool":
    r"""
    OEReadSurface(std::string const & fname, OESurface surf) -> bool
    OEReadSurface(oeistream ifs, OESurface surf, unsigned int type) -> bool
    """
    return _oespicoli.OEReadSurface(*args)

def OEWriteSurface(*args) -> "bool":
    r"""
    OEWriteSurface(std::string const & fname, OESurface surf) -> bool
    OEWriteSurface(oeostream ofs, OESurface surf, unsigned int type) -> bool
    """
    return _oespicoli.OEWriteSurface(*args)

def OEInitSurfaceHandlers(*args) -> "bool":
    r"""
    OEInitSurfaceHandlers(oemolstreambase fs)
    OEInitSurfaceHandlers(OEBinaryIOHandlerBase b) -> bool
    """
    return _oespicoli.OEInitSurfaceHandlers(*args)

def OEReduceSurface(*args) -> "bool":
    r"""OEReduceSurface(OESurface reducedSurface, OESurface original, unsigned int targetNumberOfVertices, unsigned int type=) -> bool"""
    return _oespicoli.OEReduceSurface(*args)

def OESurfaceToJSONBytes(*args) -> "PyObject *":
    r"""OESurfaceToJSONBytes(OESurface surf, unsigned int flavor=) -> PyObject"""
    return _oespicoli.OESurfaceToJSONBytes(*args)

def OEJSONToSurfaceBytes(surf: "OESurface", bytes: "PyObject *") -> "PyObject *":
    r"""OEJSONToSurfaceBytes(OESurface surf, PyObject * bytes) -> PyObject *"""
    return _oespicoli.OEJSONToSurfaceBytes(surf, bytes)

def OESetSurfaceValue(rec: "OERecord", field: "OESurfaceField", surf: "OESurface") -> "bool":
    r"""OESetSurfaceValue(OERecord rec, OESurfaceField field, OESurface surf) -> bool"""
    return _oespicoli.OESetSurfaceValue(rec, field, surf)

def OEInitSurfaceFieldHandler() -> "OEDataFlow::OEFieldTypeHandler *":
    r"""OEInitSurfaceFieldHandler() -> OEFieldTypeHandler"""
    return _oespicoli.OEInitSurfaceFieldHandler()

def OEInitSurfaceVecFieldHandler() -> "OEDataFlow::OEFieldTypeHandler *":
    r"""OEInitSurfaceVecFieldHandler() -> OEFieldTypeHandler"""
    return _oespicoli.OEInitSurfaceVecFieldHandler()
class OESurfaceType(oechem.OEFieldTypeHandler):
    r"""Proxy of C++ OEDataFlow::OEFieldType< OESpicoli::OESurface > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def format(surf: "OESurface") -> "std::string":
        r"""format(OESurface surf) -> std::string"""
        return _oespicoli.OESurfaceType_format(surf)

    def is_cacheable(self) -> "bool":
        r"""is_cacheable(OESurfaceType self) -> bool"""
        return _oespicoli.OESurfaceType_is_cacheable(self)

    def get_name(self) -> "std::string":
        r"""get_name(OESurfaceType self) -> std::string"""
        return _oespicoli.OESurfaceType_get_name(self)

    def bytes_to_json(self, bytes: "OEUCharVector") -> "std::string":
        r"""bytes_to_json(OESurfaceType self, OEUCharVector bytes) -> std::string"""
        return _oespicoli.OESurfaceType_bytes_to_json(self, bytes)

    def __init__(self):
        r"""__init__(OESurfaceType self) -> OESurfaceType"""
        _oespicoli.OESurfaceType_swiginit(self, _oespicoli.new_OESurfaceType())
    __swig_destroy__ = _oespicoli.delete_OESurfaceType

# Register OESurfaceType in _oespicoli:
_oespicoli.OESurfaceType_swigregister(OESurfaceType)
cvar = _oespicoli.cvar

def OESurfaceType_format(surf: "OESurface") -> "std::string":
    r"""OESurfaceType_format(OESurface surf) -> std::string"""
    return _oespicoli.OESurfaceType_format(surf)

class OESurfaceVecType(oechem.OEFieldTypeHandler):
    r"""Proxy of C++ OEDataFlow::OEVectorFieldType< OESpicoli::OESurface > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def format(val: "std::vector< OEStdOptionalNamespace::optional< OESpicoli::OESurface >,std::allocator< OEStdOptionalNamespace::optional< OESpicoli::OESurface > > > const &") -> "std::string":
        r"""format(std::vector< OEStdOptionalNamespace::optional< OESpicoli::OESurface >,std::allocator< OEStdOptionalNamespace::optional< OESpicoli::OESurface > > > const & val) -> std::string"""
        return _oespicoli.OESurfaceVecType_format(val)

    @staticmethod
    def GetCopyForCache(*args) -> "std::shared_ptr< std::vector< std::optional< OESpicoli::OESurface >,std::allocator< std::optional< OESpicoli::OESurface > > > >":
        r"""
        GetCopyForCache(std::vector< OESpicoli::OESurface,std::allocator< OESpicoli::OESurface > > const & val) -> std::shared_ptr< std::vector< OEStdOptionalNamespace::optional< OESpicoli::OESurface >,std::allocator< OEStdOptionalNamespace::optional< OESpicoli::OESurface > > > >
        GetCopyForCache(std::vector< std::optional< OESpicoli::OESurface >,std::allocator< std::optional< OESpicoli::OESurface > > > const & val) -> std::shared_ptr< std::vector< std::optional< OESpicoli::OESurface >,std::allocator< std::optional< OESpicoli::OESurface > > > >
        """
        return _oespicoli.OESurfaceVecType_GetCopyForCache(*args)

    def get_name(self) -> "std::string":
        r"""get_name(OESurfaceVecType self) -> std::string"""
        return _oespicoli.OESurfaceVecType_get_name(self)

    def bytes_to_json(self, bytes: "OEUCharVector") -> "std::string":
        r"""bytes_to_json(OESurfaceVecType self, OEUCharVector bytes) -> std::string"""
        return _oespicoli.OESurfaceVecType_bytes_to_json(self, bytes)

    def __init__(self):
        r"""__init__(OESurfaceVecType self) -> OESurfaceVecType"""
        _oespicoli.OESurfaceVecType_swiginit(self, _oespicoli.new_OESurfaceVecType())
    __swig_destroy__ = _oespicoli.delete_OESurfaceVecType

# Register OESurfaceVecType in _oespicoli:
_oespicoli.OESurfaceVecType_swigregister(OESurfaceVecType)

def OESurfaceVecType_format(val: "std::vector< OEStdOptionalNamespace::optional< OESpicoli::OESurface >,std::allocator< OEStdOptionalNamespace::optional< OESpicoli::OESurface > > > const &") -> "std::string":
    r"""OESurfaceVecType_format(std::vector< OEStdOptionalNamespace::optional< OESpicoli::OESurface >,std::allocator< OEStdOptionalNamespace::optional< OESpicoli::OESurface > > > const & val) -> std::string"""
    return _oespicoli.OESurfaceVecType_format(val)

def OESurfaceVecType_GetCopyForCache(*args) -> "std::shared_ptr< std::vector< std::optional< OESpicoli::OESurface >,std::allocator< std::optional< OESpicoli::OESurface > > > >":
    r"""
    OESurfaceVecType_GetCopyForCache(std::vector< OESpicoli::OESurface,std::allocator< OESpicoli::OESurface > > const & val) -> std::shared_ptr< std::vector< OEStdOptionalNamespace::optional< OESpicoli::OESurface >,std::allocator< OEStdOptionalNamespace::optional< OESpicoli::OESurface > > > >
    OESurfaceVecType_GetCopyForCache(std::vector< std::optional< OESpicoli::OESurface >,std::allocator< std::optional< OESpicoli::OESurface > > > const & val) -> std::shared_ptr< std::vector< std::optional< OESpicoli::OESurface >,std::allocator< std::optional< OESpicoli::OESurface > > > >
    """
    return _oespicoli.OESurfaceVecType_GetCopyForCache(*args)

class OESurfaceField(oechem.OEFieldBase):
    r"""Proxy of C++ OEDataFlow::OEField< OESpicoli::OESurface > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OESurfaceField self, std::string const & name, OEFieldMeta meta=OEDataFlow::OEFieldMeta(), bool readonly=False, bool nullable=False) -> OESurfaceField
        __init__(OESurfaceField self, OEFieldBase other) -> OESurfaceField
        """
        _oespicoli.OESurfaceField_swiginit(self, _oespicoli.new_OESurfaceField(*args))

    def deserialize(self, value: "OESurface", data: "OEUCharVector") -> "bool":
        r"""deserialize(OESurfaceField self, OESurface value, OEUCharVector data) -> bool"""
        return _oespicoli.OESurfaceField_deserialize(self, value, data)

    def get_type(self) -> "OEDataFlow::OEFieldType< OESpicoli::OESurface >":
        r"""get_type(OESurfaceField self) -> OESurfaceType"""
        return _oespicoli.OESurfaceField_get_type(self)
    __swig_destroy__ = _oespicoli.delete_OESurfaceField

# Register OESurfaceField in _oespicoli:
_oespicoli.OESurfaceField_swigregister(OESurfaceField)

class OESurfaceVecField(oechem.OEFieldBase):
    r"""Proxy of C++ OEDataFlow::OEVectorField< OESpicoli::OESurface > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OESurfaceVecField self, std::string const & name, OEFieldMeta meta=OEDataFlow::OEFieldMeta(), bool readonly=False, bool nullable=False) -> OESurfaceVecField
        __init__(OESurfaceVecField self, OEFieldBase f) -> OESurfaceVecField
        """
        _oespicoli.OESurfaceVecField_swiginit(self, _oespicoli.new_OESurfaceVecField(*args))

    def deserialize(self, *args) -> "bool":
        r"""
        deserialize(OESurfaceVecField self, std::vector< std::optional< OESpicoli::OESurface >,std::allocator< std::optional< OESpicoli::OESurface > > > & ret, OEUCharVector data) -> bool
        deserialize(OESurfaceVecField self, std::vector< OESpicoli::OESurface,std::allocator< OESpicoli::OESurface > > & ret, OEUCharVector data) -> bool
        """
        return _oespicoli.OESurfaceVecField_deserialize(self, *args)

    def get_type(self) -> "OEDataFlow::OEVectorFieldType< OESpicoli::OESurface >":
        r"""get_type(OESurfaceVecField self) -> OESurfaceVecType"""
        return _oespicoli.OESurfaceVecField_get_type(self)
    __swig_destroy__ = _oespicoli.delete_OESurfaceVecField

# Register OESurfaceVecField in _oespicoli:
_oespicoli.OESurfaceVecField_swigregister(OESurfaceVecField)

class OESurfaceMatchField(OESurfaceField):
    r"""Proxy of C++ OEDataFlow::OEMatchField< OESpicoli::OESurface > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""__init__(OESurfaceMatchField self, std::string const & name, OEFieldMeta meta=OEDataFlow::OEFieldMeta(), bool readonly=False, bool nullable=False) -> OESurfaceMatchField"""
        _oespicoli.OESurfaceMatchField_swiginit(self, _oespicoli.new_OESurfaceMatchField(*args))
    __swig_destroy__ = _oespicoli.delete_OESurfaceMatchField

# Register OESurfaceMatchField in _oespicoli:
_oespicoli.OESurfaceMatchField_swigregister(OESurfaceMatchField)

class OESurfaceVecMatchField(OESurfaceVecField):
    r"""Proxy of C++ OEDataFlow::OEMatchVectorField< OESpicoli::OESurface > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""__init__(OESurfaceVecMatchField self, std::string const & name, OEFieldMeta meta=OEDataFlow::OEFieldMeta(), bool readonly=False, bool nullable=False) -> OESurfaceVecMatchField"""
        _oespicoli.OESurfaceVecMatchField_swiginit(self, _oespicoli.new_OESurfaceVecMatchField(*args))
    __swig_destroy__ = _oespicoli.delete_OESurfaceVecMatchField

# Register OESurfaceVecMatchField in _oespicoli:
_oespicoli.OESurfaceVecMatchField_swigregister(OESurfaceVecMatchField)


oechem.Types.Chem.Surface = OESurfaceType()
oechem.Types.Chem.SurfaceVec = OESurfaceVecType()
oechem.Types.Chem.SurfaceVec.__class__.scalar_type = oechem.Types.Chem.Surface

OESurfaceType.valid_types = (OESurface,)






#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# Cache custom color atoms onto a molecule to be used by FastROCS

import os
import sys

from openeye import oechem
from openeye import oeshape
from openeye import oefastrocs

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))

COLOR_FORCE_FIELD = """#
TYPE negative
#
#
PATTERN negative [-]
PATTERN negative [OD1+0]-[!#7D3]~[OD1+0]
PATTERN negative [OD1+0]-[!#7D4](~[OD1+0])~[OD1+0]
#
#
INTERACTION negative negative attractive gaussian weight=1.0 radius=1.0
"""


def main(argv=[__name__]):
    if len(argv) != 3:
        oechem.OEThrow.Usage("%s <input> <output>" % argv[0])

    # input - preserve rotor-offset-compression
    ifs = oechem.oemolistream()
    ihand = ifs.GetBinaryIOHandler()
    ihand.Clear()
    oechem.OEInitHandler(ihand, oechem.OEBRotCompressOpts(), oechem.OEBRotCompressOpts())

    ifname = argv[1]
    if not ifs.open(ifname):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])

    # output
    ofname = argv[2]
    oformt = oechem.OEGetFileType(oechem.OEGetFileExtension(ofname))
    if oformt != oechem.OEFormat_OEB:
        oechem.OEThrow.Fatal("Output file format much be OEB")

    ofs = oechem.oemolostream()
    if not ofs.open(ofname):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % ofname)

    iss = oechem.oeisstream(COLOR_FORCE_FIELD)
    cff = oeshape.OEColorForceField()
    if not cff.Init(iss):
        oechem.OEThrow.Fatal("Unable to initialize OEColorForceField")

    dots = oechem.OEDots(10000, 200, "molecules")
    for mol in ifs.GetOEMols():
        oefastrocs.OEPrepareFastROCSMol(mol, cff)

        oechem.OEWriteMolecule(ofs, mol)

        dots.Update()

    dots.Total()
    ofs.close()

    print("Indexing %s" % ofname)
    if not oechem.OECreateMolDatabaseIdx(ofname):
        oechem.OEThrow.Fatal("Failed to index %s" % argv[2])

    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "CC(=O)Nc1c[nH]cc1")


class PredHasDoubleBondO(oechem.OEUnaryAtomPred):
    def __call__(self, atom):
        for bond in atom.GetBonds():
            if bond.GetOrder() == 2 and bond.GetNbr(atom).IsOxygen():
                return True
        return False


# @ <SNIPPET-PRED-PYBOND>
def AmideBond(bond):
    if bond.GetOrder() != 1:
        return False
    atomB = bond.GetBgn()
    atomE = bond.GetEnd()
    pred = PredHasDoubleBondO()
    if atomB.IsCarbon() and atomE.IsNitrogen() and pred(atomB):
        return True
    if atomB.IsNitrogen() and atomE.IsCarbon() and pred(atomE):
        return True
    return False


print("Number of amide bonds =", oechem.OECount(mol, oechem.PyBondPredicate(AmideBond)))
# @ </SNIPPET-PRED-PYBOND>
# @ </SNIPPET>



# CONFIDENTIAL. (C) 2017 OpenEye Scientific Software Inc.
# All rights reserved.
# 
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO OPENEYE
# SCIENTIFIC SOFTWARE INC., AND IS SUBJECT TO THE FULL PROTECTION OF
# COPYRIGHT AND TRADESECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from OpenEye is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact OpenEye at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")


def swig_import_helper():
    from os.path import dirname
    import importlib.util

    spec = importlib.machinery.PathFinder().find_spec("_oechem", [dirname(__file__)])

    if spec is None:
        # OpenEye Import Statements
        spec = importlib.machinery.PathFinder().find_spec("libs",[dirname(__file__)])
    libs = importlib.util.module_from_spec(spec)

    import sys
    sys.modules[spec.name] = libs
    spec.loader.exec_module(libs)

    assert not sys.platform.startswith('win')

    _oestats = libs.OEGetModule('_oestats01001')
    return _oestats

_oestats = swig_import_helper()
del swig_import_helper

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import weakref

import openeye.oechem as oechem
OEKrigeKernelType_Linear = _oestats.OEKrigeKernelType_Linear

OEKrigeKernelType_Exponential = _oestats.OEKrigeKernelType_Exponential

OEKrigeKernelType_Gaussian = _oestats.OEKrigeKernelType_Gaussian

OEKrigeKernelType_Spherical = _oestats.OEKrigeKernelType_Spherical

OEKrigeKernelType_Cauchy = _oestats.OEKrigeKernelType_Cauchy

OEKrigeKernelType_Custom = _oestats.OEKrigeKernelType_Custom

KrigeUniqueResponseMethod_meanVal = _oestats.KrigeUniqueResponseMethod_meanVal

KrigeUniqueResponseMethod_minVal = _oestats.KrigeUniqueResponseMethod_minVal

KrigeUniqueResponseMethod_maxVal = _oestats.KrigeUniqueResponseMethod_maxVal

KrigeOptionDefaults_numLocal = _oestats.KrigeOptionDefaults_numLocal

KrigeOptionDefaults_includeUnmeasured = _oestats.KrigeOptionDefaults_includeUnmeasured

KrigeOptionDefaults_maxVariogramSize = _oestats.KrigeOptionDefaults_maxVariogramSize

KrigeOptionDefaults_predictTraining = _oestats.KrigeOptionDefaults_predictTraining

KrigeOptionDefaults_uniqueResponseMethod = _oestats.KrigeOptionDefaults_uniqueResponseMethod

class OEKrigeKernelBase(object):
    r"""Proxy of C++ OEStats::OEKrigeKernelBase class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetName(self) -> "std::string":
        r"""GetName(OEKrigeKernelBase self) -> std::string"""
        return _oestats.OEKrigeKernelBase_GetName(self)

    def GetValue(self, distance: "double") -> "double":
        r"""GetValue(OEKrigeKernelBase self, double distance) -> double"""
        return _oestats.OEKrigeKernelBase_GetValue(self, distance)

    def GetRange(self) -> "double":
        r"""GetRange(OEKrigeKernelBase self) -> double"""
        return _oestats.OEKrigeKernelBase_GetRange(self)

    def GetNugget(self) -> "double":
        r"""GetNugget(OEKrigeKernelBase self) -> double"""
        return _oestats.OEKrigeKernelBase_GetNugget(self)

    def GetSill(self) -> "double":
        r"""GetSill(OEKrigeKernelBase self) -> double"""
        return _oestats.OEKrigeKernelBase_GetSill(self)

    def SetRange(self, range: "double") -> "OEStats::OEKrigeKernelBase &":
        r"""SetRange(OEKrigeKernelBase self, double range) -> OEKrigeKernelBase"""
        return _oestats.OEKrigeKernelBase_SetRange(self, range)

    def SetNugget(self, nugget: "double") -> "OEStats::OEKrigeKernelBase &":
        r"""SetNugget(OEKrigeKernelBase self, double nugget) -> OEKrigeKernelBase"""
        return _oestats.OEKrigeKernelBase_SetNugget(self, nugget)

    def SetSill(self, sill: "double") -> "OEStats::OEKrigeKernelBase &":
        r"""SetSill(OEKrigeKernelBase self, double sill) -> OEKrigeKernelBase"""
        return _oestats.OEKrigeKernelBase_SetSill(self, sill)

    def CreateCopy(self, *args):
        try:
            return _oestats.OEKrigeKernelBase_CreateCopy(self, *args)
        except RuntimeError:
            try:
                return self.__class__().__disown__()
            except:
                raise RuntimeError("CreateCopy must be specialized for %s" % self.__class__.__name__)


    __swig_destroy__ = _oestats.delete_OEKrigeKernelBase

    def __init__(self):
        r"""__init__(OEKrigeKernelBase self) -> OEKrigeKernelBase"""
        if self.__class__ == OEKrigeKernelBase:
            _self = None
        else:
            _self = self
        _oestats.OEKrigeKernelBase_swiginit(self, _oestats.new_OEKrigeKernelBase(_self, ))
    def __disown__(self):
        self.this.disown()
        _oestats.disown_OEKrigeKernelBase(self)
        return weakref.proxy(self)

# Register OEKrigeKernelBase in _oestats:
_oestats.OEKrigeKernelBase_swigregister(OEKrigeKernelBase)

class OEKrigeKernel(OEKrigeKernelBase):
    r"""Proxy of C++ OEStats::OEKrigeKernel class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetName(self) -> "std::string":
        r"""GetName(OEKrigeKernel self) -> std::string"""
        return _oestats.OEKrigeKernel_GetName(self)

    def GetValue(self, distance: "double") -> "double":
        r"""GetValue(OEKrigeKernel self, double distance) -> double"""
        return _oestats.OEKrigeKernel_GetValue(self, distance)

    def GetRange(self) -> "double":
        r"""GetRange(OEKrigeKernel self) -> double"""
        return _oestats.OEKrigeKernel_GetRange(self)

    def GetNugget(self) -> "double":
        r"""GetNugget(OEKrigeKernel self) -> double"""
        return _oestats.OEKrigeKernel_GetNugget(self)

    def GetSill(self) -> "double":
        r"""GetSill(OEKrigeKernel self) -> double"""
        return _oestats.OEKrigeKernel_GetSill(self)

    def SetRange(self, range: "double") -> "OEStats::OEKrigeKernelBase &":
        r"""SetRange(OEKrigeKernel self, double range) -> OEKrigeKernelBase"""
        return _oestats.OEKrigeKernel_SetRange(self, range)

    def SetNugget(self, nugget: "double") -> "OEStats::OEKrigeKernelBase &":
        r"""SetNugget(OEKrigeKernel self, double nugget) -> OEKrigeKernelBase"""
        return _oestats.OEKrigeKernel_SetNugget(self, nugget)

    def SetSill(self, sill: "double") -> "OEStats::OEKrigeKernelBase &":
        r"""SetSill(OEKrigeKernel self, double sill) -> OEKrigeKernelBase"""
        return _oestats.OEKrigeKernel_SetSill(self, sill)

    def CreateCopy(self, *args):
        try:
            return _oestats.OEKrigeKernel_CreateCopy(self, *args)
        except RuntimeError:
            try:
                return self.__class__().__disown__()
            except:
                raise RuntimeError("CreateCopy must be specialized for %s" % self.__class__.__name__)



    def __init__(self, *args):
        r"""
        __init__(OEKrigeKernel self, unsigned int type=) -> OEKrigeKernel
        __init__(OEKrigeKernel self, OEKrigeKernelBase kernel) -> OEKrigeKernel
        """
        _oestats.OEKrigeKernel_swiginit(self, _oestats.new_OEKrigeKernel(*args))
    __swig_destroy__ = _oestats.delete_OEKrigeKernel

# Register OEKrigeKernel in _oestats:
_oestats.OEKrigeKernel_swigregister(OEKrigeKernel)

class OEVariogram(object):
    r"""Proxy of C++ OEStats::OEVariogram class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetNumBins(self) -> "unsigned int":
        r"""GetNumBins(OEVariogram self) -> unsigned int"""
        return _oestats.OEVariogram_GetNumBins(self)

    def GetDistance(self, iBin: "unsigned int") -> "double":
        r"""GetDistance(OEVariogram self, unsigned int iBin) -> double"""
        return _oestats.OEVariogram_GetDistance(self, iBin)

    def GetSemivariance(self, iBin: "unsigned int") -> "double":
        r"""GetSemivariance(OEVariogram self, unsigned int iBin) -> double"""
        return _oestats.OEVariogram_GetSemivariance(self, iBin)

    def __init__(self, *args):
        r"""
        __init__(OEVariogram self) -> OEVariogram
        __init__(OEVariogram self, OEStats::OEVariogramBase * impl) -> OEVariogram
        __init__(OEVariogram self, OEVariogram rhs) -> OEVariogram
        """
        _oestats.OEVariogram_swiginit(self, _oestats.new_OEVariogram(*args))
    __swig_destroy__ = _oestats.delete_OEVariogram

# Register OEVariogram in _oestats:
_oestats.OEVariogram_swigregister(OEVariogram)


def OEFitKernel(kernel: "OEKrigeKernelBase", variogram: "OEVariogram") -> "double":
    r"""OEFitKernel(OEKrigeKernelBase kernel, OEVariogram variogram) -> double"""
    return _oestats.OEFitKernel(kernel, variogram)

def OEFitKernelPartial(kernel: "OEKrigeKernelBase", variogram: "OEVariogram", fracPoints: "double") -> "double":
    r"""OEFitKernelPartial(OEKrigeKernelBase kernel, OEVariogram variogram, double fracPoints) -> double"""
    return _oestats.OEFitKernelPartial(kernel, variogram, fracPoints)

def OEGetExperimentalVariance(arg1: "OEVariogram") -> "double":
    r"""OEGetExperimentalVariance(OEVariogram arg1) -> double"""
    return _oestats.OEGetExperimentalVariance(arg1)

def OEGetFitness(kernel: "OEKrigeKernelBase", variogram: "OEVariogram") -> "double":
    r"""OEGetFitness(OEKrigeKernelBase kernel, OEVariogram variogram) -> double"""
    return _oestats.OEGetFitness(kernel, variogram)
class OEGlobalKrigeOptions(object):
    r"""Proxy of C++ OEStats::OEGlobalKrigeOptions class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetIncludeUnmeasured(self) -> "bool":
        r"""GetIncludeUnmeasured(OEGlobalKrigeOptions self) -> bool"""
        return _oestats.OEGlobalKrigeOptions_GetIncludeUnmeasured(self)

    def GetUniqueResponseMethod(self) -> "unsigned int":
        r"""GetUniqueResponseMethod(OEGlobalKrigeOptions self) -> unsigned int"""
        return _oestats.OEGlobalKrigeOptions_GetUniqueResponseMethod(self)

    def SetIncludeUnmeasured(self, *args) -> "OEStats::OEGlobalKrigeOptions &":
        r"""SetIncludeUnmeasured(OEGlobalKrigeOptions self, bool arg2=) -> OEGlobalKrigeOptions"""
        return _oestats.OEGlobalKrigeOptions_SetIncludeUnmeasured(self, *args)

    def SetUniqueResponseMethod(self, *args) -> "OEStats::OEGlobalKrigeOptions &":
        r"""SetUniqueResponseMethod(OEGlobalKrigeOptions self, unsigned int arg2=) -> OEGlobalKrigeOptions"""
        return _oestats.OEGlobalKrigeOptions_SetUniqueResponseMethod(self, *args)

    def __init__(self):
        r"""__init__(OEGlobalKrigeOptions self) -> OEGlobalKrigeOptions"""
        _oestats.OEGlobalKrigeOptions_swiginit(self, _oestats.new_OEGlobalKrigeOptions())
    __swig_destroy__ = _oestats.delete_OEGlobalKrigeOptions

# Register OEGlobalKrigeOptions in _oestats:
_oestats.OEGlobalKrigeOptions_swigregister(OEGlobalKrigeOptions)

class OELocalKrigeOptions(object):
    r"""Proxy of C++ OEStats::OELocalKrigeOptions class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetIncludeUnmeasured(self) -> "bool":
        r"""GetIncludeUnmeasured(OELocalKrigeOptions self) -> bool"""
        return _oestats.OELocalKrigeOptions_GetIncludeUnmeasured(self)

    def GetUniqueResponseMethod(self) -> "unsigned int":
        r"""GetUniqueResponseMethod(OELocalKrigeOptions self) -> unsigned int"""
        return _oestats.OELocalKrigeOptions_GetUniqueResponseMethod(self)

    def GetNumLocal(self) -> "unsigned int":
        r"""GetNumLocal(OELocalKrigeOptions self) -> unsigned int"""
        return _oestats.OELocalKrigeOptions_GetNumLocal(self)

    def GetMaxVariogramSize(self) -> "unsigned int":
        r"""GetMaxVariogramSize(OELocalKrigeOptions self) -> unsigned int"""
        return _oestats.OELocalKrigeOptions_GetMaxVariogramSize(self)

    def GetPredictTraining(self) -> "bool":
        r"""GetPredictTraining(OELocalKrigeOptions self) -> bool"""
        return _oestats.OELocalKrigeOptions_GetPredictTraining(self)

    def SetIncludeUnmeasured(self, *args) -> "OEStats::OELocalKrigeOptions &":
        r"""SetIncludeUnmeasured(OELocalKrigeOptions self, bool arg2=) -> OELocalKrigeOptions"""
        return _oestats.OELocalKrigeOptions_SetIncludeUnmeasured(self, *args)

    def SetNumLocal(self, *args) -> "OEStats::OELocalKrigeOptions &":
        r"""SetNumLocal(OELocalKrigeOptions self, unsigned int arg2=) -> OELocalKrigeOptions"""
        return _oestats.OELocalKrigeOptions_SetNumLocal(self, *args)

    def SetUniqueResponseMethod(self, *args) -> "OEStats::OELocalKrigeOptions &":
        r"""SetUniqueResponseMethod(OELocalKrigeOptions self, unsigned int arg2=) -> OELocalKrigeOptions"""
        return _oestats.OELocalKrigeOptions_SetUniqueResponseMethod(self, *args)

    def SetMaxVariogramSize(self, *args) -> "OEStats::OELocalKrigeOptions &":
        r"""SetMaxVariogramSize(OELocalKrigeOptions self, unsigned int arg2=) -> OELocalKrigeOptions"""
        return _oestats.OELocalKrigeOptions_SetMaxVariogramSize(self, *args)

    def SetPredictTraining(self, *args) -> "OEStats::OELocalKrigeOptions &":
        r"""SetPredictTraining(OELocalKrigeOptions self, bool arg2=) -> OELocalKrigeOptions"""
        return _oestats.OELocalKrigeOptions_SetPredictTraining(self, *args)

    def __init__(self):
        r"""__init__(OELocalKrigeOptions self) -> OELocalKrigeOptions"""
        _oestats.OELocalKrigeOptions_swiginit(self, _oestats.new_OELocalKrigeOptions())
    __swig_destroy__ = _oestats.delete_OELocalKrigeOptions

# Register OELocalKrigeOptions in _oestats:
_oestats.OELocalKrigeOptions_swigregister(OELocalKrigeOptions)

class OEDefaultKrigeDistanceOptions(object):
    r"""Proxy of C++ OEStats::OEDefaultKrigeDistanceOptions class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def GetMaxPathLength(self) -> "unsigned int":
        r"""GetMaxPathLength(OEDefaultKrigeDistanceOptions self) -> unsigned int"""
        return _oestats.OEDefaultKrigeDistanceOptions_GetMaxPathLength(self)

    def GetMinPathLength(self) -> "unsigned int":
        r"""GetMinPathLength(OEDefaultKrigeDistanceOptions self) -> unsigned int"""
        return _oestats.OEDefaultKrigeDistanceOptions_GetMinPathLength(self)

    def GetForcePathsOut(self) -> "bool":
        r"""GetForcePathsOut(OEDefaultKrigeDistanceOptions self) -> bool"""
        return _oestats.OEDefaultKrigeDistanceOptions_GetForcePathsOut(self)

    def GetWeightByLength(self) -> "bool":
        r"""GetWeightByLength(OEDefaultKrigeDistanceOptions self) -> bool"""
        return _oestats.OEDefaultKrigeDistanceOptions_GetWeightByLength(self)

    def GetStereoAware(self) -> "bool":
        r"""GetStereoAware(OEDefaultKrigeDistanceOptions self) -> bool"""
        return _oestats.OEDefaultKrigeDistanceOptions_GetStereoAware(self)

    def SetMaxPathLength(self, arg2: "unsigned int") -> "OEStats::OEDefaultKrigeDistanceOptions &":
        r"""SetMaxPathLength(OEDefaultKrigeDistanceOptions self, unsigned int arg2) -> OEDefaultKrigeDistanceOptions"""
        return _oestats.OEDefaultKrigeDistanceOptions_SetMaxPathLength(self, arg2)

    def SetMinPathLength(self, arg2: "unsigned int") -> "OEStats::OEDefaultKrigeDistanceOptions &":
        r"""SetMinPathLength(OEDefaultKrigeDistanceOptions self, unsigned int arg2) -> OEDefaultKrigeDistanceOptions"""
        return _oestats.OEDefaultKrigeDistanceOptions_SetMinPathLength(self, arg2)

    def SetForcePathsOut(self, arg2: "bool") -> "OEStats::OEDefaultKrigeDistanceOptions &":
        r"""SetForcePathsOut(OEDefaultKrigeDistanceOptions self, bool arg2) -> OEDefaultKrigeDistanceOptions"""
        return _oestats.OEDefaultKrigeDistanceOptions_SetForcePathsOut(self, arg2)

    def SetWeightByLength(self, arg2: "bool") -> "OEStats::OEDefaultKrigeDistanceOptions &":
        r"""SetWeightByLength(OEDefaultKrigeDistanceOptions self, bool arg2) -> OEDefaultKrigeDistanceOptions"""
        return _oestats.OEDefaultKrigeDistanceOptions_SetWeightByLength(self, arg2)

    def SetStereoAware(self, arg2: "bool") -> "OEStats::OEDefaultKrigeDistanceOptions &":
        r"""SetStereoAware(OEDefaultKrigeDistanceOptions self, bool arg2) -> OEDefaultKrigeDistanceOptions"""
        return _oestats.OEDefaultKrigeDistanceOptions_SetStereoAware(self, arg2)

    def GetImpl(self) -> "OEGraphSim::OEVseprOptions const *":
        r"""GetImpl(OEDefaultKrigeDistanceOptions self) -> OEGraphSim::OEVseprOptions const *"""
        return _oestats.OEDefaultKrigeDistanceOptions_GetImpl(self)

    def __init__(self, *args):
        r"""
        __init__(OEDefaultKrigeDistanceOptions self) -> OEDefaultKrigeDistanceOptions
        __init__(OEDefaultKrigeDistanceOptions self, OEDefaultKrigeDistanceOptions rhs) -> OEDefaultKrigeDistanceOptions
        """
        _oestats.OEDefaultKrigeDistanceOptions_swiginit(self, _oestats.new_OEDefaultKrigeDistanceOptions(*args))
    __swig_destroy__ = _oestats.delete_OEDefaultKrigeDistanceOptions

# Register OEDefaultKrigeDistanceOptions in _oestats:
_oestats.OEDefaultKrigeDistanceOptions_swigregister(OEDefaultKrigeDistanceOptions)

class OEMolKrigeResult(object):
    r"""Proxy of C++ OEStats::OEMolKrigeResult class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Valid(self) -> "bool":
        r"""Valid(OEMolKrigeResult self) -> bool"""
        return _oestats.OEMolKrigeResult_Valid(self)

    def GetResponse(self) -> "double":
        r"""GetResponse(OEMolKrigeResult self) -> double"""
        return _oestats.OEMolKrigeResult_GetResponse(self)

    def GetVariance(self) -> "double":
        r"""GetVariance(OEMolKrigeResult self) -> double"""
        return _oestats.OEMolKrigeResult_GetVariance(self)

    def GetAtomContribution(self, *args) -> "double":
        r"""
        GetAtomContribution(OEMolKrigeResult self, OEAtomBase atom) -> double
        GetAtomContribution(OEMolKrigeResult self, OEAtomBase atom) -> double
        GetAtomContribution(OEMolKrigeResult self, OEAtomBase atom, double baseline) -> double
        GetAtomContribution(OEMolKrigeResult self, OEAtomBase atom, double baseline) -> double
        """
        return _oestats.OEMolKrigeResult_GetAtomContribution(self, *args)

    def GetKernel(self) -> "OEStats::OEKrigeKernel":
        r"""GetKernel(OEMolKrigeResult self) -> OEKrigeKernel"""
        return _oestats.OEMolKrigeResult_GetKernel(self)

    def GetVariogram(self) -> "OEStats::OEVariogram":
        r"""GetVariogram(OEMolKrigeResult self) -> OEVariogram"""
        return _oestats.OEMolKrigeResult_GetVariogram(self)

    def GetNumElements(self) -> "unsigned int":
        r"""GetNumElements(OEMolKrigeResult self) -> unsigned int"""
        return _oestats.OEMolKrigeResult_GetNumElements(self)

    def GetElementDistance(self, iElement: "unsigned int") -> "double":
        r"""GetElementDistance(OEMolKrigeResult self, unsigned int iElement) -> double"""
        return _oestats.OEMolKrigeResult_GetElementDistance(self, iElement)

    def GetElementWeight(self, iElement: "unsigned int") -> "double":
        r"""GetElementWeight(OEMolKrigeResult self, unsigned int iElement) -> double"""
        return _oestats.OEMolKrigeResult_GetElementWeight(self, iElement)

    def GetElementResponse(self, iElement: "unsigned int") -> "double":
        r"""GetElementResponse(OEMolKrigeResult self, unsigned int iElement) -> double"""
        return _oestats.OEMolKrigeResult_GetElementResponse(self, iElement)

    def GetElementIsUnmeasured(self, iElement: "unsigned int") -> "bool":
        r"""GetElementIsUnmeasured(OEMolKrigeResult self, unsigned int iElement) -> bool"""
        return _oestats.OEMolKrigeResult_GetElementIsUnmeasured(self, iElement)

    def GetElement(self, iElement: "unsigned int") -> "OEChem::OEMolBase const &":
        r"""GetElement(OEMolKrigeResult self, unsigned int iElement) -> OEMolBase"""
        return _oestats.OEMolKrigeResult_GetElement(self, iElement)

    def GetTrainingResponses(self, incUnmeasured: "bool"=True) -> "OESystem::OEIterBase< double > *":
        r"""GetTrainingResponses(OEMolKrigeResult self, bool incUnmeasured=True) -> OESystem::OEIterBase< double >"""
        return _oestats.OEMolKrigeResult_GetTrainingResponses(self, incUnmeasured)

    def __init__(self, *args):
        r"""
        __init__(OEMolKrigeResult self) -> OEMolKrigeResult
        __init__(OEMolKrigeResult self, OEStats::OEMolKrigeResultImpl * impl) -> OEMolKrigeResult
        __init__(OEMolKrigeResult self, OEMolKrigeResult rhs) -> OEMolKrigeResult
        """
        _oestats.OEMolKrigeResult_swiginit(self, _oestats.new_OEMolKrigeResult(*args))
    __swig_destroy__ = _oestats.delete_OEMolKrigeResult

# Register OEMolKrigeResult in _oestats:
_oestats.OEMolKrigeResult_swigregister(OEMolKrigeResult)


def OEProbabilityLessThan(arg1: "OEMolKrigeResult", val: "double") -> "double":
    r"""OEProbabilityLessThan(OEMolKrigeResult arg1, double val) -> double"""
    return _oestats.OEProbabilityLessThan(arg1, val)

def OEProbabilityGreaterThan(arg1: "OEMolKrigeResult", val: "double") -> "double":
    r"""OEProbabilityGreaterThan(OEMolKrigeResult arg1, double val) -> double"""
    return _oestats.OEProbabilityGreaterThan(arg1, val)

def OEProbabilityBetween(arg1: "OEMolKrigeResult", val1: "double", val2: "double") -> "double":
    r"""OEProbabilityBetween(OEMolKrigeResult arg1, double val1, double val2) -> double"""
    return _oestats.OEProbabilityBetween(arg1, val1, val2)
class OEMolKrige(object):
    r"""Proxy of C++ OEStats::OEMolKrige class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def AddTraining(self, *args) -> "bool":
        r"""
        AddTraining(OEMolKrige self, OEMolBase arg2, double response) -> bool
        AddTraining(OEMolKrige self, OEMCMolBase arg2, double response) -> bool
        """
        return _oestats.OEMolKrige_AddTraining(self, *args)

    def AddUnmeasuredTraining(self, *args) -> "bool":
        r"""
        AddUnmeasuredTraining(OEMolKrige self, OEMolBase arg2, double response) -> bool
        AddUnmeasuredTraining(OEMolKrige self, OEMCMolBase arg2, double response) -> bool
        """
        return _oestats.OEMolKrige_AddUnmeasuredTraining(self, *args)

    def Train(self, *args) -> "bool":
        r"""
        Train(OEMolKrige self) -> bool
        Train(OEMolKrige self, OEKrigeKernel arg2) -> bool
        """
        return _oestats.OEMolKrige_Train(self, *args)

    def TrainFixed(self, arg2: "OEKrigeKernel") -> "bool":
        r"""TrainFixed(OEMolKrige self, OEKrigeKernel arg2) -> bool"""
        return _oestats.OEMolKrige_TrainFixed(self, arg2)

    def GetResult(self, *args) -> "OEStats::OEMolKrigeResult":
        r"""
        GetResult(OEMolKrige self, OEMolBase arg2) -> OEMolKrigeResult
        GetResult(OEMolKrige self, OEMolBase arg2) -> OEMolKrigeResult
        GetResult(OEMolKrige self, OEMCMolBase arg2) -> OEMolKrigeResult
        GetResult(OEMolKrige self, OEMCMolBase arg2) -> OEMolKrigeResult
        """
        return _oestats.OEMolKrige_GetResult(self, *args)

    def GetVariogram(self, *args) -> "OEStats::OEVariogram":
        r"""
        GetVariogram(OEMolKrige self) -> OEVariogram
        GetVariogram(OEMolKrige self) -> OEVariogram
        """
        return _oestats.OEMolKrige_GetVariogram(self, *args)

    def Clear(self) -> "void":
        r"""Clear(OEMolKrige self)"""
        return _oestats.OEMolKrige_Clear(self)

    def __init__(self, *args):
        r"""
        __init__(OEMolKrige self, OEGlobalKrigeOptions arg2=OEStats::OEGlobalKrigeOptions()) -> OEMolKrige
        __init__(OEMolKrige self, OELocalKrigeOptions arg2) -> OEMolKrige
        __init__(OEMolKrige self, OEDefaultKrigeDistanceOptions arg2, OEGlobalKrigeOptions arg3=OEStats::OEGlobalKrigeOptions()) -> OEMolKrige
        __init__(OEMolKrige self, OEDefaultKrigeDistanceOptions arg2, OELocalKrigeOptions arg3) -> OEMolKrige
        __init__(OEMolKrige self, OEMolPropertyList trendPropFxn, OEGlobalKrigeOptions arg3=OEStats::OEGlobalKrigeOptions()) -> OEMolKrige
        __init__(OEMolKrige self, OEMolPropertyList trendPropFxn, OELocalKrigeOptions arg3) -> OEMolKrige
        __init__(OEMolKrige self, OEDefaultKrigeDistanceOptions arg2, OEMolPropertyList trendPropFxn, OEGlobalKrigeOptions arg4=OEStats::OEGlobalKrigeOptions()) -> OEMolKrige
        __init__(OEMolKrige self, OEDefaultKrigeDistanceOptions arg2, OEMolPropertyList trendPropFxn, OELocalKrigeOptions arg4) -> OEMolKrige
        __init__(OEMolKrige self, OEMolKrigeDistFxn distFxn, OEGlobalKrigeOptions arg3=OEStats::OEGlobalKrigeOptions()) -> OEMolKrige
        __init__(OEMolKrige self, OEMolKrigeDistFxn distFxn, OELocalKrigeOptions arg3) -> OEMolKrige
        __init__(OEMolKrige self, OEMolKrigeDistFxn distFxn, OEMolPropertyList trendPropFxn, OEGlobalKrigeOptions arg4=OEStats::OEGlobalKrigeOptions()) -> OEMolKrige
        __init__(OEMolKrige self, OEMolKrigeDistFxn distFxn, OEMolPropertyList trendPropFxn, OELocalKrigeOptions arg4) -> OEMolKrige
        __init__(OEMolKrige self, OEMolKrige rhs) -> OEMolKrige
        """
        _oestats.OEMolKrige_swiginit(self, _oestats.new_OEMolKrige(*args))
    __swig_destroy__ = _oestats.delete_OEMolKrige

# Register OEMolKrige in _oestats:
_oestats.OEMolKrige_swigregister(OEMolKrige)

class OEMolKrigeDistFxn(object):
    r"""Proxy of C++ OESystem::OEBinaryFunction< OEChem::OEMolBase,OEChem::OEMolBase,double,true,true > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __swig_destroy__ = _oestats.delete_OEMolKrigeDistFxn

    def __call__(self, a1: "OEMolBase", a2: "OEMolBase") -> "double":
        r"""__call__(OEMolKrigeDistFxn self, OEMolBase a1, OEMolBase a2) -> double"""
        return _oestats.OEMolKrigeDistFxn___call__(self, a1, a2)

    def CreateCopy(self, *args):
        try:
            return _oestats.OEMolKrigeDistFxn_CreateCopy(self, *args)
        except RuntimeError:
            try:
                return self.__class__().__disown__()
            except:
                raise RuntimeError("CreateCopy must be specialized for %s" % self.__class__.__name__)



    def __init__(self):
        r"""__init__(OEMolKrigeDistFxn self) -> OEMolKrigeDistFxn"""
        if self.__class__ == OEMolKrigeDistFxn:
            _self = None
        else:
            _self = self
        _oestats.OEMolKrigeDistFxn_swiginit(self, _oestats.new_OEMolKrigeDistFxn(_self, ))
    def __disown__(self):
        self.this.disown()
        _oestats.disown_OEMolKrigeDistFxn(self)
        return weakref.proxy(self)

# Register OEMolKrigeDistFxn in _oestats:
_oestats.OEMolKrigeDistFxn_swigregister(OEMolKrigeDistFxn)

class OEMolKrigeDefaultDistFxn(OEMolKrigeDistFxn):
    r"""Proxy of C++ OEStats::OEMolKrigeDefaultDistFxn class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __call__(self, arg2: "OEMolBase", arg3: "OEMolBase") -> "double":
        r"""__call__(OEMolKrigeDefaultDistFxn self, OEMolBase arg2, OEMolBase arg3) -> double"""
        return _oestats.OEMolKrigeDefaultDistFxn___call__(self, arg2, arg3)

    def PrepMol(self, arg2: "OEMolBase") -> "bool":
        r"""PrepMol(OEMolKrigeDefaultDistFxn self, OEMolBase arg2) -> bool"""
        return _oestats.OEMolKrigeDefaultDistFxn_PrepMol(self, arg2)

    def CreateCopy(self, *args):
        try:
            return _oestats.OEMolKrigeDefaultDistFxn_CreateCopy(self, *args)
        except RuntimeError:
            try:
                return self.__class__().__disown__()
            except:
                raise RuntimeError("CreateCopy must be specialized for %s" % self.__class__.__name__)



    def __init__(self, *args):
        r"""__init__(OEMolKrigeDefaultDistFxn self, OEDefaultKrigeDistanceOptions arg2=OEStats::OEDefaultKrigeDistanceOptions()) -> OEMolKrigeDefaultDistFxn"""
        _oestats.OEMolKrigeDefaultDistFxn_swiginit(self, _oestats.new_OEMolKrigeDefaultDistFxn(*args))
    __swig_destroy__ = _oestats.delete_OEMolKrigeDefaultDistFxn

# Register OEMolKrigeDefaultDistFxn in _oestats:
_oestats.OEMolKrigeDefaultDistFxn_swigregister(OEMolKrigeDefaultDistFxn)

class OEMolKrigeGraphSimDistFxn(OEMolKrigeDistFxn):
    r"""Proxy of C++ OEStats::OEMolKrigeGraphSimDistFxn class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __call__(self, arg2: "OEMolBase", arg3: "OEMolBase") -> "double":
        r"""__call__(OEMolKrigeGraphSimDistFxn self, OEMolBase arg2, OEMolBase arg3) -> double"""
        return _oestats.OEMolKrigeGraphSimDistFxn___call__(self, arg2, arg3)

    def PrepMol(self, arg2: "OEMolBase") -> "bool":
        r"""PrepMol(OEMolKrigeGraphSimDistFxn self, OEMolBase arg2) -> bool"""
        return _oestats.OEMolKrigeGraphSimDistFxn_PrepMol(self, arg2)

    def CreateCopy(self, *args):
        try:
            return _oestats.OEMolKrigeGraphSimDistFxn_CreateCopy(self, *args)
        except RuntimeError:
            try:
                return self.__class__().__disown__()
            except:
                raise RuntimeError("CreateCopy must be specialized for %s" % self.__class__.__name__)



    def __init__(self, *args):
        r"""__init__(OEMolKrigeGraphSimDistFxn self, unsigned int fpType=OEGraphSim::OEFPType::Path) -> OEMolKrigeGraphSimDistFxn"""
        _oestats.OEMolKrigeGraphSimDistFxn_swiginit(self, _oestats.new_OEMolKrigeGraphSimDistFxn(*args))
    __swig_destroy__ = _oestats.delete_OEMolKrigeGraphSimDistFxn

# Register OEMolKrigeGraphSimDistFxn in _oestats:
_oestats.OEMolKrigeGraphSimDistFxn_swigregister(OEMolKrigeGraphSimDistFxn)

class OEKrigeReportOptions(object):
    r"""Proxy of C++ OEStats::OEKrigeReportOptions class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def SetTitle(self, title: "std::string") -> "void":
        r"""SetTitle(OEKrigeReportOptions self, std::string title)"""
        return _oestats.OEKrigeReportOptions_SetTitle(self, title)

    def SetResponseName(self, name: "std::string") -> "void":
        r"""SetResponseName(OEKrigeReportOptions self, std::string name)"""
        return _oestats.OEKrigeReportOptions_SetResponseName(self, name)

    def SetResponseSignificantFigures(self, arg2: "unsigned int") -> "void":
        r"""SetResponseSignificantFigures(OEKrigeReportOptions self, unsigned int arg2)"""
        return _oestats.OEKrigeReportOptions_SetResponseSignificantFigures(self, arg2)

    def SetShowConfidence(self, show: "bool") -> "void":
        r"""SetShowConfidence(OEKrigeReportOptions self, bool show)"""
        return _oestats.OEKrigeReportOptions_SetShowConfidence(self, show)

    def SetUnlog(self, unlog: "bool") -> "void":
        r"""SetUnlog(OEKrigeReportOptions self, bool unlog)"""
        return _oestats.OEKrigeReportOptions_SetUnlog(self, unlog)

    def SetContributionPositiveColor(self, arg2: "OEColor") -> "void":
        r"""SetContributionPositiveColor(OEKrigeReportOptions self, OEColor arg2)"""
        return _oestats.OEKrigeReportOptions_SetContributionPositiveColor(self, arg2)

    def SetContributionNegativeColor(self, arg2: "OEColor") -> "void":
        r"""SetContributionNegativeColor(OEKrigeReportOptions self, OEColor arg2)"""
        return _oestats.OEKrigeReportOptions_SetContributionNegativeColor(self, arg2)

    def SetContributionPositiveLabel(self, arg2: "std::string") -> "void":
        r"""SetContributionPositiveLabel(OEKrigeReportOptions self, std::string arg2)"""
        return _oestats.OEKrigeReportOptions_SetContributionPositiveLabel(self, arg2)

    def SetContributionNegativeLabel(self, arg2: "std::string") -> "void":
        r"""SetContributionNegativeLabel(OEKrigeReportOptions self, std::string arg2)"""
        return _oestats.OEKrigeReportOptions_SetContributionNegativeLabel(self, arg2)

    def SetContributionBaseline(self, baseline: "double") -> "void":
        r"""SetContributionBaseline(OEKrigeReportOptions self, double baseline)"""
        return _oestats.OEKrigeReportOptions_SetContributionBaseline(self, baseline)

    def PushSDProperty(self, *args) -> "void":
        r"""
        PushSDProperty(OEKrigeReportOptions self, std::string tag)
        PushSDProperty(OEKrigeReportOptions self, std::string tag, std::string name)
        """
        return _oestats.OEKrigeReportOptions_PushSDProperty(self, *args)

    def PushProperty(self, arg2: "OEMolPropertyFxn", name: "std::string", sigFigs: "unsigned int"=4) -> "void":
        r"""PushProperty(OEKrigeReportOptions self, OEMolPropertyFxn arg2, std::string name, unsigned int sigFigs=4)"""
        return _oestats.OEKrigeReportOptions_PushProperty(self, arg2, name, sigFigs)

    def PushClassificationBoundry(self, value: "double") -> "void":
        r"""PushClassificationBoundry(OEKrigeReportOptions self, double value)"""
        return _oestats.OEKrigeReportOptions_PushClassificationBoundry(self, value)

    def PushClassificationColor(self, color: "OEColor") -> "void":
        r"""PushClassificationColor(OEKrigeReportOptions self, OEColor color)"""
        return _oestats.OEKrigeReportOptions_PushClassificationColor(self, color)

    def SetShowKrigeDetails(self, show: "bool") -> "void":
        r"""SetShowKrigeDetails(OEKrigeReportOptions self, bool show)"""
        return _oestats.OEKrigeReportOptions_SetShowKrigeDetails(self, show)

    def GetTitle(self) -> "std::string":
        r"""GetTitle(OEKrigeReportOptions self) -> std::string"""
        return _oestats.OEKrigeReportOptions_GetTitle(self)

    def GetResponseName(self) -> "std::string":
        r"""GetResponseName(OEKrigeReportOptions self) -> std::string"""
        return _oestats.OEKrigeReportOptions_GetResponseName(self)

    def GetResponseSignificantFigures(self) -> "unsigned int":
        r"""GetResponseSignificantFigures(OEKrigeReportOptions self) -> unsigned int"""
        return _oestats.OEKrigeReportOptions_GetResponseSignificantFigures(self)

    def GetShowConfidence(self) -> "bool":
        r"""GetShowConfidence(OEKrigeReportOptions self) -> bool"""
        return _oestats.OEKrigeReportOptions_GetShowConfidence(self)

    def GetUnlog(self) -> "bool":
        r"""GetUnlog(OEKrigeReportOptions self) -> bool"""
        return _oestats.OEKrigeReportOptions_GetUnlog(self)

    def GetContributionPositiveColor(self) -> "OESystem::OEColor":
        r"""GetContributionPositiveColor(OEKrigeReportOptions self) -> OEColor"""
        return _oestats.OEKrigeReportOptions_GetContributionPositiveColor(self)

    def GetContributionNegativeColor(self) -> "OESystem::OEColor":
        r"""GetContributionNegativeColor(OEKrigeReportOptions self) -> OEColor"""
        return _oestats.OEKrigeReportOptions_GetContributionNegativeColor(self)

    def GetContributionPositiveLabel(self) -> "std::string":
        r"""GetContributionPositiveLabel(OEKrigeReportOptions self) -> std::string"""
        return _oestats.OEKrigeReportOptions_GetContributionPositiveLabel(self)

    def GetContributionNegativeLabel(self) -> "std::string":
        r"""GetContributionNegativeLabel(OEKrigeReportOptions self) -> std::string"""
        return _oestats.OEKrigeReportOptions_GetContributionNegativeLabel(self)

    def GetHasContributionBaseline(self) -> "bool":
        r"""GetHasContributionBaseline(OEKrigeReportOptions self) -> bool"""
        return _oestats.OEKrigeReportOptions_GetHasContributionBaseline(self)

    def GetContributionBaseline(self) -> "double":
        r"""GetContributionBaseline(OEKrigeReportOptions self) -> double"""
        return _oestats.OEKrigeReportOptions_GetContributionBaseline(self)

    def GetNumProperties(self) -> "unsigned int":
        r"""GetNumProperties(OEKrigeReportOptions self) -> unsigned int"""
        return _oestats.OEKrigeReportOptions_GetNumProperties(self)

    def GetPropertyName(self, iProp: "unsigned int") -> "std::string":
        r"""GetPropertyName(OEKrigeReportOptions self, unsigned int iProp) -> std::string"""
        return _oestats.OEKrigeReportOptions_GetPropertyName(self, iProp)

    def GetPropertyValue(self, *args) -> "std::string":
        r"""
        GetPropertyValue(OEKrigeReportOptions self, unsigned int iProp, OEMolBase arg3) -> std::string
        GetPropertyValue(OEKrigeReportOptions self, unsigned int iProp, OEMCMolBase arg3) -> std::string
        """
        return _oestats.OEKrigeReportOptions_GetPropertyValue(self, *args)

    def GetNumClassifications(self) -> "unsigned int":
        r"""GetNumClassifications(OEKrigeReportOptions self) -> unsigned int"""
        return _oestats.OEKrigeReportOptions_GetNumClassifications(self)

    def GetClassificationColor(self, iClass: "unsigned int") -> "OESystem::OEColor":
        r"""GetClassificationColor(OEKrigeReportOptions self, unsigned int iClass) -> OEColor"""
        return _oestats.OEKrigeReportOptions_GetClassificationColor(self, iClass)

    def GetClassificationUpperBound(self, iClass: "unsigned int") -> "double":
        r"""GetClassificationUpperBound(OEKrigeReportOptions self, unsigned int iClass) -> double"""
        return _oestats.OEKrigeReportOptions_GetClassificationUpperBound(self, iClass)

    def GetClassificationLowerBound(self, iClass: "unsigned int") -> "double":
        r"""GetClassificationLowerBound(OEKrigeReportOptions self, unsigned int iClass) -> double"""
        return _oestats.OEKrigeReportOptions_GetClassificationLowerBound(self, iClass)

    def GetShowKrigeDetails(self) -> "bool":
        r"""GetShowKrigeDetails(OEKrigeReportOptions self) -> bool"""
        return _oestats.OEKrigeReportOptions_GetShowKrigeDetails(self)

    def ClearTitle(self) -> "void":
        r"""ClearTitle(OEKrigeReportOptions self)"""
        return _oestats.OEKrigeReportOptions_ClearTitle(self)

    def ClearContributionLabels(self) -> "void":
        r"""ClearContributionLabels(OEKrigeReportOptions self)"""
        return _oestats.OEKrigeReportOptions_ClearContributionLabels(self)

    def ClearContributionBaseline(self) -> "void":
        r"""ClearContributionBaseline(OEKrigeReportOptions self)"""
        return _oestats.OEKrigeReportOptions_ClearContributionBaseline(self)

    def ClearProperties(self) -> "void":
        r"""ClearProperties(OEKrigeReportOptions self)"""
        return _oestats.OEKrigeReportOptions_ClearProperties(self)

    def ClearClassifications(self) -> "void":
        r"""ClearClassifications(OEKrigeReportOptions self)"""
        return _oestats.OEKrigeReportOptions_ClearClassifications(self)

    def Clear(self) -> "void":
        r"""Clear(OEKrigeReportOptions self)"""
        return _oestats.OEKrigeReportOptions_Clear(self)

    def __init__(self, *args):
        r"""
        __init__(OEKrigeReportOptions self) -> OEKrigeReportOptions
        __init__(OEKrigeReportOptions self, OEKrigeReportOptions arg2) -> OEKrigeReportOptions
        """
        _oestats.OEKrigeReportOptions_swiginit(self, _oestats.new_OEKrigeReportOptions(*args))
    __swig_destroy__ = _oestats.delete_OEKrigeReportOptions

# Register OEKrigeReportOptions in _oestats:
_oestats.OEKrigeReportOptions_swigregister(OEKrigeReportOptions)


def OEKrigeRenderReport(*args) -> "bool":
    r"""
    OEKrigeRenderReport(OEDepict::OEImageBase & image, OEMolKrigeResult result, OEMolBase mol, OEKrigeReportOptions opts, unsigned int trainRows=0, unsigned int trainCols=0) -> bool
    OEKrigeRenderReport(OEDepict::OEImageBase & image, OEMolKrigeResult result, OEMCMolBase mol, OEKrigeReportOptions opts, unsigned int trainRows=0, unsigned int trainCols=0) -> bool
    OEKrigeRenderReport(std::string filename, OEMolKrigeResult result, OEMolBase mol, OEKrigeReportOptions opts=OEStats::OEKrigeReportOptions()) -> bool
    OEKrigeRenderReport(std::string filename, OEMolKrigeResult result, OEMCMolBase mol, OEKrigeReportOptions opts=OEStats::OEKrigeReportOptions()) -> bool
    """
    return _oestats.OEKrigeRenderReport(*args)
class OEMolLog10PropertyFxn(oechem.OEMolPropertyFxn):
    r"""Proxy of C++ OEStats::OEMolLog10PropertyFxn class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(OEMolLog10PropertyFxn self, OEMolPropertyFxn fxn) -> OEMolLog10PropertyFxn
        __init__(OEMolLog10PropertyFxn self, OEMolLog10PropertyFxn prop) -> OEMolLog10PropertyFxn
        """
        _oestats.OEMolLog10PropertyFxn_swiginit(self, _oestats.new_OEMolLog10PropertyFxn(*args))

    def Has(self, *args) -> "bool":
        r"""
        Has(OEMolLog10PropertyFxn self, OEMolBase mol) -> bool
        Has(OEMolLog10PropertyFxn self, OEMCMolBase mol) -> bool
        """
        return _oestats.OEMolLog10PropertyFxn_Has(self, *args)

    def Get(self, *args) -> "double":
        r"""
        Get(OEMolLog10PropertyFxn self, OEMolBase mol) -> double
        Get(OEMolLog10PropertyFxn self, OEMCMolBase mol) -> double
        """
        return _oestats.OEMolLog10PropertyFxn_Get(self, *args)

    def CreateCopy(self, *args):
        try:
            return _oestats.OEMolLog10PropertyFxn_CreateCopy(self, *args)
        except RuntimeError:
            try:
                return self.__class__().__disown__()
            except:
                raise RuntimeError("CreateCopy must be specialized for %s" % self.__class__.__name__)


    __swig_destroy__ = _oestats.delete_OEMolLog10PropertyFxn

# Register OEMolLog10PropertyFxn in _oestats:
_oestats.OEMolLog10PropertyFxn_swigregister(OEMolLog10PropertyFxn)

class OEMolecularWeightPropertyFxn(oechem.OEMolPropertyFxn):
    r"""Proxy of C++ OEStats::OEMolecularWeightPropertyFxn class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Has(self, *args) -> "bool":
        r"""
        Has(OEMolecularWeightPropertyFxn self, OEMolBase mol) -> bool
        Has(OEMolecularWeightPropertyFxn self, OEMCMolBase mol) -> bool
        """
        return _oestats.OEMolecularWeightPropertyFxn_Has(self, *args)

    def Get(self, *args) -> "double":
        r"""
        Get(OEMolecularWeightPropertyFxn self, OEMolBase mol) -> double
        Get(OEMolecularWeightPropertyFxn self, OEMCMolBase mol) -> double
        """
        return _oestats.OEMolecularWeightPropertyFxn_Get(self, *args)

    def CreateCopy(self, *args):
        try:
            return _oestats.OEMolecularWeightPropertyFxn_CreateCopy(self, *args)
        except RuntimeError:
            try:
                return self.__class__().__disown__()
            except:
                raise RuntimeError("CreateCopy must be specialized for %s" % self.__class__.__name__)



    def __init__(self):
        r"""__init__(OEMolecularWeightPropertyFxn self) -> OEMolecularWeightPropertyFxn"""
        _oestats.OEMolecularWeightPropertyFxn_swiginit(self, _oestats.new_OEMolecularWeightPropertyFxn())
    __swig_destroy__ = _oestats.delete_OEMolecularWeightPropertyFxn

# Register OEMolecularWeightPropertyFxn in _oestats:
_oestats.OEMolecularWeightPropertyFxn_swigregister(OEMolecularWeightPropertyFxn)

OE_OESTATS_VERSION = _oestats.OE_OESTATS_VERSION


def OEStatsGetRelease() -> "char const *":
    r"""OEStatsGetRelease() -> char const *"""
    return _oestats.OEStatsGetRelease()

def OEStatsGetVersion() -> "unsigned int":
    r"""OEStatsGetVersion() -> unsigned int"""
    return _oestats.OEStatsGetVersion()

def OEStatsGetArch() -> "char const *":
    r"""OEStatsGetArch() -> char const *"""
    return _oestats.OEStatsGetArch()

def OEStatsGetPlatform() -> "char const *":
    r"""OEStatsGetPlatform() -> char const *"""
    return _oestats.OEStatsGetPlatform()

def OEStatsIsLicensed(feature: "char const *"=None, expdate: "unsigned int *"=None) -> "bool":
    r"""OEStatsIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool"""
    return _oestats.OEStatsIsLicensed(feature, expdate)

def OEStatsGetLicensee(*args) -> "std::string":
    r"""
    OEStatsGetLicensee(std::string & licensee) -> bool
    OEStatsGetLicensee() -> std::string
    """
    return _oestats.OEStatsGetLicensee(*args)

def OEStatsGetSite(*args) -> "std::string":
    r"""
    OEStatsGetSite(std::string & site) -> bool
    OEStatsGetSite() -> std::string
    """
    return _oestats.OEStatsGetSite(*args)





#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oedocking


def main(argv=[__name__]):
    positOpts = oedocking.OEPositOptions()
    opts = oechem.OERefInputAppOptions(positOpts, "PoseMolecules", oechem.OEFileStringType_Mol3D,
                                       oechem.OEFileStringType_DU, oechem.OEFileStringType_DU, "-receptor")
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    positOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    rfs = oechem.oeifstream()
    if not rfs.open(opts.GetRefFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetRefFile())

    ofs = oechem.oeofstream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    du = oechem.OEDesignUnit()
    if not oechem.OEReadDesignUnit(rfs, du):
        oechem.OEThrow.Fatal("Failed to read design unit")
    if not du.HasReceptor():
        oechem.OEThrow.Fatal("Design unit %s does not contain a receptor" % du.GetTitle())

    # @ <SNIPPET-POSE-MOLECULES-SETUP>
    poser = oedocking.OEPosit(positOpts)
    # @ </SNIPPET-POSE-MOLECULES-SETUP>
    # @ <SNIPPET-POSE-MOLECULES-INITIALIZE>
    poser.AddReceptor(du)
    # @ </SNIPPET-POSE-MOLECULES-INITIALIZE>

    for mcmol in ifs.GetOEMols():
        print("posing", mcmol.GetTitle())
        # @ <SNIPPET-POSE-MOLECULES-DOCK>
        result = oedocking.OESinglePoseResult()
        ret_code = poser.Dock(result, mcmol)
        # @ </SNIPPET-POSE-MOLECULES-DOCK>

        if ret_code == oedocking.OEDockingReturnCode_Success:
            posedDU = result.GetDesignUnit()
            posedDU.SetDoubleData(poser.GetName(), result.GetProbability())
            oechem.OEWriteDesignUnit(ofs, posedDU)
        else:
            errMsg = oedocking.OEDockingReturnCodeGetName(ret_code)
            oechem.OEThrow.Warning("%s: %s" % (mcmol.GetTitle(), errMsg))
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Filter out molecules by their molecular weight or heavy atom count
#############################################################################
import sys
from openeye import oechem


def IsBetween(min, max, val):
    if min <= val <= max:
        return True
    return False


def IsMoleculeInHeavyAtomCountRange(min, max, mol):
    count = oechem.OECount(mol, oechem.OEIsHeavy())
    return IsBetween(min, max, count)


def IsMoleculeInMolWtRange(min, max, mol):
    molwt = oechem.OECalculateMolecularWeight(mol)
    return IsBetween(min, max, molwt)


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    ifs = oechem.oemolistream()
    if not ifs.open(itf.GetString("-i")):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % itf.GetString("-i"))

    ofs = oechem.oemolostream(".ism")
    if itf.HasString("-o"):
        if not ofs.open(itf.GetString("-o")):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-o"))

    minhac = float("-inf")
    if itf.HasInt("-minhac"):
        minhac = itf.GetInt("-minhac")
    maxhac = float("inf")
    if itf.HasInt("-maxhac"):
        maxhac = itf.GetInt("-maxhac")
    minwt = float("-inf")
    if itf.HasDouble("-minwt"):
        minwt = itf.GetDouble("-minwt")
    maxwt = float("inf")
    if itf.HasDouble("-maxwt"):
        maxwt = itf.GetDouble("-maxwt")

    for mol in ifs.GetOEMols():
        if not IsMoleculeInHeavyAtomCountRange(minhac, maxhac, mol):
            continue
        if not IsMoleculeInMolWtRange(minwt, maxwt, mol):
            continue

        oechem.OEWriteMolecule(ofs, mol)


InterfaceData = """
!BRIEF [-minhac <num>] [-maxhac <num>] [-minwt <num>] [-maxwt <num>] [-i] <input> [[-o] <output>]
!PARAMETER -i
  !TYPE string
  !REQUIRED true
  !BRIEF Input file name
  !KEYLESS 1
!END
!PARAMETER -o
  !TYPE string
  !REQUIRED false
  !BRIEF Output file name
  !KEYLESS 2
!END
!PARAMETER -minhac
  !TYPE int
  !REQUIRED false
  !BRIEF minimum heavy atom count
!END
!PARAMETER -maxhac
  !TYPE int
  !REQUIRED false
  !BRIEF maximum heavy atom count
!END
!PARAMETER -minwt
  !TYPE double
  !REQUIRED false
  !BRIEF minimum molecular weight
!END
!PARAMETER -maxwt
  !TYPE double
  !REQUIRED false
  !BRIEF maximum molecular weight
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oeszybki


class MyOptions(oechem.OEOptions):
    def __init__(self):
        oechem.OEOptions.__init__(self, "MyOption")
        self._optOpts = oeszybki.OEProteinLigandOptOptions()
        self._flexOpts = oeszybki.OEProteinFlexOptions()
        self.AddOption(self._optOpts)
        self.AddOption(self._flexOpts)
        pass

    def CreateCopy(self):
        return self

    def GetOptOptions(self):
        return self._optOpts

    def GetFlexOptions(self):
        return self._flexOpts


def main(argv=[__name__]):
    myOpts = MyOptions()
    opts = oechem.OESimpleAppOptions(myOpts, "OptimizeDU", oechem.OEFileStringType_DU, oechem.OEFileStringType_DU)
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    optOpts = myOpts.GetOptOptions()
    flexOpts = myOpts.GetFlexOptions()
    optOpts.UpdateValues(opts)
    flexOpts.UpdateValues(opts)

    ifs = oechem.oeifstream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    ofs = oechem.oeofstream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    optimizer = oeszybki.OEFlexProteinLigandOptimizer(optOpts)
    du = oechem.OEDesignUnit()
    while oechem.OEReadDesignUnit(ifs, du):
        oechem.OEThrow.Info("Title: %s" % du.GetTitle())
        res = oeszybki.OEProteinLigandOptResults()
        proteinMask = oechem.OEDesignUnitComponents_Protein
        retCode = optimizer.Optimize(res, du, proteinMask, oechem.OEDesignUnitComponents_Ligand, flexOpts)
        if retCode == oeszybki.OESzybkiReturnCode_Success:
            initEne = res.GetInitialEnergies()
            oechem.OEThrow.Info("Initial energies:")
            oechem.OEThrow.Info("  Ligand: %0.2f" % initEne.GetLigandEnergy())
            oechem.OEThrow.Info("  Flexible Protein: %0.2f" % initEne.GetHostEnergy())
            oechem.OEThrow.Info("  Intermolecular: %0.2f" % initEne.GetInterEnergy())
            oechem.OEThrow.Info("  Total: %0.2f" % initEne.GetTotalEnergy())
            finalEne = res.GetFinalEnergies()
            oechem.OEThrow.Info("Final energies:")
            oechem.OEThrow.Info("  Ligand: %0.2f" % finalEne.GetLigandEnergy())
            oechem.OEThrow.Info("  Flexible Protein: %0.2f" % finalEne.GetHostEnergy())
            oechem.OEThrow.Info("  Intermolecular: %0.2f" % finalEne.GetInterEnergy())
            oechem.OEThrow.Info("  Total: %0.2f" % finalEne.GetTotalEnergy())
            oechem.OEWriteDesignUnit(ofs, du)
        else:
            oechem.OEThrow.Warning("%s: %s" % (du.GetTitle(), oeszybki.OEGetSzybkiError(retCode)))
    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.
import sys
from openeye import oechem


# @ <SNIPPET-PREDICATE>
class MoleculeWeightPredicate(oechem.OEUnaryMolBasePred):
    def __init__(self, minweight, maxweight):
        oechem.OEUnaryMolBasePred.__init__(self)
        self.minweight = minweight
        self.maxweight = maxweight

    def __call__(self, mol):
        weight = oechem.OECalculateMolecularWeight(mol)
        return (weight >= self.minweight and weight <= self.maxweight)

    def CreateCopy(self):
        # __disown__ is required to allow C++ to take ownership of this
        # object and its memory
        return MoleculeWeightPredicate(self.minweight, self.maxweight).__disown__()
# @ </SNIPPET-PREDICATE>


if len(sys.argv) != 2:
    oechem.OEThrow.Usage("%s <ssdatabase>" % sys.argv[0])

dbfname = sys.argv[1]

screentype = oechem.OEGetSubSearchScreenType(oechem.OESubSearchScreenType_SMARTS)

if not oechem.OEIsValidSubSearchDatabase(dbfname, screentype):
    oechem.OEThrow.Fatal("Invalid SMARTS substructure search database file!")

nrthreads = 1
# @ <SNIPPET>
ssdb = oechem.OESubSearchDatabase(dbfname, oechem.OESubSearchDatabaseType_Default, nrthreads)

qmol = oechem.OEQMol()
oechem.OEParseSmarts(qmol, "c1c[n,o]cc1")

maxmatches = 100
query = oechem.OESubSearchQuery(qmol, maxmatches)

result = oechem.OESubSearchResult()
ssdb.Search(result, query)
print("Number of total matches = {}".format(result.NumTotalMatches()))

# search filtered by molecule weight

minweight, maxweight = 200.0, 350.0
query.SetFilter(MoleculeWeightPredicate(minweight, maxweight))

filteredresult = oechem.OESubSearchResult()
ssdb.Search(filteredresult, query)
print("Number of total matches (filtered) = {}".format(filteredresult.NumTotalMatches()))

mol = oechem.OEGraphMol()
for index in filteredresult.GetMatchIndices():
    if ssdb.GetMolecule(mol, index):
        print("weight= {:.3f} {}".format(oechem.OECalculateMolecularWeight(mol), oechem.OEMolToSmiles(mol)))
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem
import sys

InterfaceData = """
!PARAMETER -i
  !TYPE string
  !KEYLESS 1
  !BRIEF Input file name
!END
!PARAMETER -o
  !TYPE string
  !KEYLESS 2
  !BRIEF Output file name
!END
"""

itf = oechem.OEInterface(InterfaceData, sys.argv)

print("Input file name =", itf.GetString("-i"))
print("Output file name =", itf.GetString("-o"))
# @ </SNIPPET>



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem


def DumpSDData(mol):
    print("SD data of", mol.GetTitle())
    # loop over SD data
    for dp in oechem.OEGetSDDataPairs(mol):
        print(dp.GetTag(), ':', dp.GetValue())
    print()


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1ccccc1")
mol.SetTitle("benzene")

# set some tagged data
oechem.OESetSDData(mol, "color", "brown")
oechem.OESetSDData(mol, oechem.OESDDataPair("size", "small"))
DumpSDData(mol)

# check for existence of data, then delete it
if oechem.OEHasSDData(mol, "size"):
    oechem.OEDeleteSDData(mol, "size")
DumpSDData(mol)

# add additional color data
oechem.OEAddSDData(mol, "color", "black")
DumpSDData(mol)

# remove all SD data
oechem.OEClearSDData(mol)
DumpSDData(mol)
# @ </SNIPPET>



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import os
import sys

from openeye import oechem
from openeye import oefastrocs

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))


def main(argv=[__name__]):
    if len(argv) < 3:
        oechem.OEThrow.Usage("%s <database> [<queries> ... ]" % argv[0])

    dbname = argv[1]
    if oechem.OEIsGZip(dbname):
        oechem.OEThrow.Fatal("%s is an unsupported database file format as it is gzipped.\n"
                             "Preferred formats are .oeb, .sdf or .oez", dbname)

    # read in database
    ifs = oechem.oemolistream()
    if not ifs.open(dbname):
        oechem.OEThrow.Fatal("Unable to open '%s'" % dbname)

    print("Opening database file %s ..." % dbname)
    timer = oechem.OEWallTimer()
    dbase = oefastrocs.OEShapeDatabase()
    moldb = oechem.OEMolDatabase()
    if not moldb.Open(ifs):
        oechem.OEThrow.Fatal("Unable to open '%s'" % dbname)

    dots = oechem.OEThreadedDots(10000, 200, "conformers")
    if not dbase.Open(moldb, dots):
        oechem.OEThrow.Fatal("Unable to initialize OEShapeDatabase on '%s'" % dbname)

    dots.Total()
    print("%s seconds to load database" % timer.Elapsed())

    opts = oefastrocs.OEShapeDatabaseOptions()
    opts.SetSimFunc(oefastrocs.OEShapeSimFuncType_Tversky)
    numHits = moldb.NumMols()
    opts.SetLimit(numHits)

    for qfname in argv[2:]:
        # read in query
        qfs = oechem.oemolistream()
        if not qfs.open(qfname):
            oechem.OEThrow.Fatal("Unable to open '%s'" % argv[1])

        query = oechem.OEGraphMol()
        if not oechem.OEReadMolecule(qfs, query):
            oechem.OEThrow.Fatal("Unable to read query from '%s'" % argv[1])

        ext = oechem.OEGetFileExtension(qfname)
        base = qfname[:-(len(ext) + 1)]

        # write out everthing to a similary named file
        ofs = oechem.oemolostream()
        ofname = base + "_results." + ext
        if not ofs.open(ofname):
            oechem.OEThrow.Fatal("Unable to open '%s'" % argv[4])

        print("Searching for %s" % qfname)
        for score in dbase.GetSortedScores(query, opts):
            dbmol = oechem.OEMol()
            molidx = score.GetMolIdx()
            if not moldb.GetMolecule(dbmol, molidx):
                print("Unable to retrieve molecule '%u' from the database" % molidx)
                continue
            mol = oechem.OEGraphMol(dbmol.GetConf(oechem.OEHasConfIdx(score.GetConfIdx())))

            oechem.OESetSDData(mol, "ShapeTversky", "%.4f" % score.GetShapeTversky())
            oechem.OESetSDData(mol, "ColorTversky", "%.4f" % score.GetColorTversky())
            oechem.OESetSDData(mol, "TverskyCombo", "%.4f" % score.GetTverskyCombo())
            score.Transform(mol)

            oechem.OEWriteMolecule(ofs, mol)
        print("Wrote results to %s" % ofname)
    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))
